<?php
/**
 * Farsi language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Peyman Hooshmandi Raad" <phooshmand@gmail.com>
 */

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'fa',
            DB_ERROR                    => 'خطای ناشناخته',
            DB_ERROR_ALREADY_EXISTS     => 'وجود دارد',
            DB_ERROR_CANNOT_CREATE      => 'امکان create وجود ندارد',
            DB_ERROR_CANNOT_DELETE      => 'امکان حذف وجود ندارد',
            DB_ERROR_CANNOT_DROP        => 'امکان drop وجود ندارد',
            DB_ERROR_CONSTRAINT         => 'نقض شرط',
            DB_ERROR_DIVZERO            => 'تقسیم بر صفر',
            DB_ERROR_INVALID            => 'نامعتبر',
            DB_ERROR_INVALID_DATE       => 'زمان یا تاریخ نامعتبر',
            DB_ERROR_INVALID_NUMBER     => 'عدد نامعتبر',
            DB_ERROR_MISMATCH           => 'عدم مطابقت',
            DB_ERROR_NODBSELECTED       => 'بانک اطلاعاتی انتخاب نشده است',
            DB_ERROR_NOSUCHFIELD        => 'چنین ستونی وجود ندارد',
            DB_ERROR_NOSUCHTABLE        => 'چنین جدولی وجود ندارد',
            DB_ERROR_NOT_CAPABLE        => 'backend بانک اطلاعاتی قادر نیست',
            DB_ERROR_NOT_FOUND          => 'پیدا نشد',
            DB_ERROR_NOT_LOCKED         => 'قفل نشده',
            DB_ERROR_SYNTAX             => 'خطای دستوری',
            DB_ERROR_UNSUPPORTED        => 'پشتیبانی نمی شود',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'شمارش مقادیر روی ردیف',
            DB_ERROR_INVALID_DSN        => 'DSN نامعتبر',
            DB_ERROR_CONNECT_FAILED     => 'ارتباط برقرار نشد',
            0	                       => 'بدون خطا', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'داده ناکافی است',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'extension پیدا نشد',
            DB_ERROR_NOSUCHDB           => 'چنین بانک اطلاعاتی وجود ندارد',
            DB_ERROR_ACCESS_VIOLATION   => 'حق دسترسی ناکافی'
);
