<?php

	/**
	 * Catalan language file for phpPgAdmin.
	 * mantainer: Bernat Pegueroles <bpf@pegueroles.com>
	 *
	 * $Id: catalan.php,v 1.4 2008/03/14 03:31:43 xzilla Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Català';
	$lang['applocale'] = 'ca-ES';
	$lang['applangdir'] = 'ltr';

	// Welcome  
	$lang['strintro'] = 'Benvingut a phpPgAdmin.';
	$lang['strppahome'] = 'Pàgina web de phpPgAdmin';
	$lang['strpgsqlhome'] = 'Pàgina web de PostgreSQL';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'Documentació PostgreSQL (local)';
	$lang['strreportbug'] = 'Reportar un Bug';
	$lang['strviewfaq'] = 'Veure FAQ online';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
	
	// Basic strings
	$lang['strlogin'] = 'Entrada';
	$lang['strloginfailed'] = 'Entrada fallida';
	$lang['strlogindisallowed'] = 'Entrada rebutjada per raons de seguretat.';
	$lang['strserver'] = 'Servidor';
	$lang['strservers'] = 'Servidors';
        $lang['strgroupservers']  =  'Servidors en el grup "%s"';
        $lang['strallservers']  =  'Tots els servidors';
	$lang['strintroduction'] = 'Introducció';
	$lang['strhost'] = 'Host';
	$lang['strport'] = 'Port';
	$lang['strlogout'] = 'Sortida';
	$lang['strowner'] = 'Propietari';
	$lang['straction'] = 'Acció';
	$lang['stractions'] = 'Accions';
	$lang['strname'] = 'Nom';
	$lang['strdefinition'] = 'Definició';
	$lang['strproperties'] = 'Propietats';
	$lang['strbrowse'] = 'Navega';
	$lang['strenable'] = 'Habilita';
	$lang['strdisable'] = 'Inhabilita';
	$lang['strdrop'] = 'Elimina';
	$lang['strdropped'] = 'Eliminat';
	$lang['strnull'] = 'Nul';
	$lang['strnotnull'] = 'No Nul';
	$lang['strprev'] = '< Previ';
	$lang['strnext'] = 'Següent >';
	$lang['strfirst'] = '<< Primer';
	$lang['strlast'] = 'Últim >>';
	$lang['strfailed'] = 'Fallat';
	$lang['strcreate'] = 'Crea';
	$lang['strcreated'] = 'Creat';
	$lang['strcomment'] = 'Comentari';
	$lang['strlength'] = 'Longitud';
	$lang['strdefault'] = 'Predeterminat';
	$lang['stralter'] = 'Modifica';
	$lang['strok'] = 'D\'acord';
	$lang['strcancel'] = 'Cancel·la';
        $lang['strkill']  =  'Mata';
	$lang['strac'] = 'Habilita AutoCompletat';
	$lang['strsave'] = 'Desa';
	$lang['strreset'] = 'Restableix';
        $lang['strrestart']  =  'Reinicia';
	$lang['strinsert'] = 'Inserta';
	$lang['strselect'] = 'Selecciona';
	$lang['strdelete'] = 'Elimina';
	$lang['strupdate'] = 'Actualitza';
	$lang['strreferences'] = 'Referències';
	$lang['stryes'] = 'Sí';
	$lang['strno'] = 'No';
	$lang['strtrue'] = 'Cert';
	$lang['strfalse'] = 'Fals';
	$lang['stredit'] = 'Edita';
	$lang['strcolumn'] = 'Columna';
	$lang['strcolumns'] = 'Columnes';
	$lang['strrows'] = 'fila(es)';
	$lang['strrowsaff'] = 'fila/es afectada/es.';
	$lang['strobjects'] = 'objecte(s)';
	$lang['strback'] = 'Enrere';
	$lang['strqueryresults'] = 'Resultat de la Consulta';
	$lang['strshow'] = 'Mostra';
	$lang['strempty'] = 'Buida';
	$lang['strlanguage'] = 'Idioma';
	$lang['strencoding'] = 'Codificació';
	$lang['strvalue'] = 'Valor';
	$lang['strunique'] = 'Únic';
	$lang['strprimary'] = 'Primari';
	$lang['strexport'] = 'Exporta';
	$lang['strimport'] = 'Importa';
	$lang['strallowednulls'] = 'Caràcters NULL Permesos';
	$lang['strbackslashn'] = '\N';
	$lang['stremptystring'] = 'Cadena o camp buit';
	$lang['strsql'] = 'SQL';
	$lang['stradmin'] = 'Admin';
	$lang['strvacuum'] = 'Vacuum';
	$lang['stranalyze'] = 'Analyze';
	$lang['strclusterindex'] = 'Clúster';
	$lang['strclustered'] = 'Clusteritzat?';
	$lang['strreindex'] = 'Reindex';
	$lang['strexecute'] = 'Executa';
	$lang['stradd'] = 'Agrega';
	$lang['strevent'] = 'Event';
	$lang['strwhere'] = 'On';
	$lang['strinstead'] = 'Fes en el seu lloc';
	$lang['strwhen'] = 'Quan';
	$lang['strformat'] = 'Format';
	$lang['strdata'] = 'Dades';
	$lang['strconfirm'] = 'Confirma';
	$lang['strexpression'] = 'Expressió';
	$lang['strellipsis'] = '...';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = 'Expandeix';
	$lang['strcollapse'] = 'Colapsa';
	$lang['strfind'] = 'Cerca';
	$lang['stroptions'] = 'Opcions';
	$lang['strrefresh'] = 'Refresca';
	$lang['strdownload'] = 'Baixa';
	$lang['strdownloadgzipped'] = 'Baixa comprimit amb gzip';
	$lang['strinfo'] = 'Informació';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = 'Avançat';
	$lang['strvariables'] = 'Variables';
	$lang['strprocess'] = 'Procés';
	$lang['strprocesses'] = 'Processos';
	$lang['strsetting'] = 'Ajustament';
	$lang['streditsql'] = 'Edita SQL';
	$lang['strruntime'] = 'Total temps d\'execució: %s ms';
	$lang['strpaginate'] = 'Pagina els resultats';
	$lang['struploadscript'] = 'o carrega un script SQL:';
	$lang['strstarttime'] = 'Hora d\'Inici';
	$lang['strfile'] = 'Fitxer';
	$lang['strfileimported'] = 'Fitxer importat.';
	$lang['strtrycred'] = 'Usa aquestes credencials a tots els servidors';
        $lang['strconfdropcred']  =  'Per raons de seguretat, la desconnexió eliminarà la informació d\'entrada compartida. Està segur de voler desconnectar ?';
	$lang['stractionsonmultiplelines'] = 'Accions a múltiples línies';
	$lang['strselectall'] = 'Seleccina\'ls tots';
	$lang['strunselectall'] = 'No en seleccionis cap';
	$lang['strlocale'] = 'Local';
        $lang['strcollation']  =  'Col·lació';
        $lang['strctype']  =  'Tipus de caràcter';
        $lang['strdefaultvalues']  =  'Valors per defecte';
        $lang['strnewvalues']  =  'Valors nous';
        $lang['strstart']  =  'Comença';
        $lang['strstop']  =  'Para';
        $lang['strgotoppage']  =  'Torna al principi';
        $lang['strtheme']  =  'Tema';
	$lang['strcluster'] = 'Clúster';
	
	// Admin
        $lang['stradminondatabase']  =  'Les següents tasques administratives s\'apliquen a tota la base de dades %s.';
        $lang['stradminontable']  =  'Les següents tasques administratives s\'apliquen a la taula %s.';

	// User-supplied SQL history
	$lang['strhistory'] = 'Història';
	$lang['strnohistory'] = 'No hi ha història.';
	$lang['strclearhistory'] = 'Neteja la història';
	$lang['strdelhistory'] = 'Elimina de la història';
	$lang['strconfdelhistory'] = 'Realment vol eliminar aquesta petició de la història?';
	$lang['strconfclearhistory'] = 'Realment vol elimnar la història?';
	$lang['strnodatabaseselected'] = 'Si us plau, seleccioni una base de dades.';

	// Database Sizes
        $lang['strnoaccess']  =  'Sense Accés'; 
	$lang['strsize'] = 'Tamany';
	$lang['strbytes'] = 'bytes';
	$lang['strkb'] = 'kB';
	$lang['strmb'] = 'MB';
	$lang['strgb'] = 'GB';
	$lang['strtb'] = 'TB';

	// Error handling
	$lang['strnoframes'] = 'Aquesta aplicació treballa millor en un navegador amb suport per frames, però es pot usar sense seguint el link de sota.';
	$lang['strnoframeslink'] = 'Usa sense frames';
	$lang['strbadconfig'] = 'El seu config.inc.php no està actualitzat. Necessitarà regenerar-lo a partir del nou config.inc.php-dist.';
	$lang['strnotloaded'] = 'La seva instal·lació de PHP no suporta la PostgreSQL. Necessita recompilar el PHP usant la opció de configuració --with-pgsql.';
	$lang['strpostgresqlversionnotsupported'] = 'Versió de PostgreSQL no suportada. Si su plau actualitzi a la versió %s o posterior.';
	$lang['strbadschema'] = 'Esquema especificat invàlid.';
	$lang['strbadencoding'] = 'Error al fixar la codificació del client a la base de dades.';
	$lang['strsqlerror'] = 'Error SQL:';
	$lang['strinstatement'] = 'En la sentència:';
	$lang['strinvalidparam'] = 'Paràmetres del script invàlids.';
	$lang['strnodata'] = 'No s\'han trobat files.';
	$lang['strnoobjects'] = 'No s\'han trobat objectes.';
	$lang['strrownotunique'] = 'No hi ha un identificador únic per aquesta fila.';
	$lang['strnouploads'] = 'La pujada de fitxers està deshabilitada.';
	$lang['strimporterror'] = 'Error d\'importació.';
	$lang['strimporterror-fileformat'] = 'Error d\'importació: Error al determinar automàticament el format del fitxer.';
	$lang['strimporterrorline'] = 'Error d\'importació a la línia %s.';
	$lang['strimporterrorline-badcolumnnum'] = 'Error d\'importació a la línia %s:  La línia no té el número correcte de columnes.';
	$lang['strimporterror-uploadedfile'] = 'Error d\'importació: El fitxer no s\'ha pogut pujar al servidor';
	$lang['strcannotdumponwindows'] = 'El volcat de dades amb noms complexos de taules i esquemes en Windows no és suportada.';
	$lang['strinvalidserverparam'] = 'Intent de connexió amb un paràmetre del servidor invàlid, possiblement algú està provant d\'entrar al sistema.'; 
	$lang['strnoserversupplied'] = 'No s\'ha proporcionat cap servidor!';
        $lang['strbadpgdumppath']  =  'Error d\'exportació: Fallada en l\'execució de pg_dump (path definit a conf/config.inc.php : %s ). Sisplau, arregli el path en la configuració.';
        $lang['strbadpgdumpallpath']  =  'Error d\'exportació: Fallada en l\'execució de pg_dumpall (path definit a conf/config.inc.php : %s ). Sisplau, arregli el path en la configuració.';
        $lang['strconnectionfail']  =  'No hi ha connexió amb el servidor.';

	// Tables
	$lang['strtable'] = 'Taula';
	$lang['strtables'] = 'Taules';
	$lang['strshowalltables'] = 'Mostra totes les taules';
	$lang['strnotables'] = 'No s\'han trobat taules.';
	$lang['strnotable'] = 'No s\'ha trobat la taula.';
	$lang['strcreatetable'] = 'Crea una taula';
	$lang['strcreatetablelike'] = 'Crea una taula com a';
	$lang['strcreatetablelikeparent'] = 'Taula origen';
	$lang['strcreatelikewithdefaults'] = 'INCLUDE DEFAULTS';
	$lang['strcreatelikewithconstraints'] = 'INCLUDE CONSTRAINTS';
	$lang['strcreatelikewithindexes'] = 'INCLUDE INDEXES';
	$lang['strtablename'] = 'Nom de la taula';
	$lang['strtableneedsname'] = 'Ha d\'anomenar la taula.';
	$lang['strtablelikeneedslike'] = 'Ha de donar una taula d\'on copiar les propietats.';
	$lang['strtableneedsfield'] = 'Ha d\'especificar almenys un camp.';
	$lang['strtableneedscols'] = 'Ha d\'especificar un número vàlid de columnes.';
	$lang['strtablecreated'] = 'Taula creada.';
	$lang['strtablecreatedbad'] = 'No s\'ha pogut crear la taula.';
	$lang['strconfdroptable'] = 'Està segur de voler eliminar la taula "%s"?';
	$lang['strtabledropped'] = 'Taula eliminada.';
	$lang['strtabledroppedbad'] = 'No s\'ha pogut eliminar la taula.';
	$lang['strconfemptytable'] = 'Està segur que vol buidar la taula "%s"?';
	$lang['strtableemptied'] = 'Taula buidada.';
	$lang['strtableemptiedbad'] = 'No s\'ha pogut buidar la taula.';
	$lang['strinsertrow'] = 'Inserta una fila';
	$lang['strrowinserted'] = 'Fila insertada.';
	$lang['strrowinsertedbad'] = 'No s\'ha pogut insertar la taula.';
        $lang['strnofkref']  =  'No hi ha cap valor coincident en la foreign key %s.';
	$lang['strrowduplicate'] = 'Inserció de la taula fallada, intentant fer una inserció duplicada.';
	$lang['streditrow'] = 'Edita la fila';
	$lang['strrowupdated'] = 'Fila actualitzada.';
	$lang['strrowupdatedbad'] = 'No s\'ha pogut actualitzar la fila.';
	$lang['strdeleterow'] = 'Elimina la fila';
	$lang['strconfdeleterow'] = 'Està segur que vol eliminar aquesta fila?';
	$lang['strrowdeleted'] = 'Fila eliminada.';
	$lang['strrowdeletedbad'] = 'No s\'ha pogut eliminar la fila.';
	$lang['strinsertandrepeat'] = 'Inserta & Repeteix';
	$lang['strnumcols'] = 'Nombre de columnes';
	$lang['strcolneedsname'] = 'Ha d\'especificar un nom per la columna';
	$lang['strselectallfields'] = 'Selecciona tots els camps';
	$lang['strselectneedscol'] = 'Ha de mostrar almenys una columna.';
	$lang['strselectunary'] = 'Els operadors unaris no poden tenir valors.';
	$lang['strcolumnaltered'] = 'Columna modificada.';
	$lang['strcolumnalteredbad'] = 'No s\'ha pogut modificar la columna.';
	$lang['strconfdropcolumn'] = 'Està segur d\'eliminar la columna "%s" de la taula "%s"?';
	$lang['strcolumndropped'] = 'Columna eliminada.';
	$lang['strcolumndroppedbad'] = 'No s\'ha pogut eliminar la columna.';
	$lang['straddcolumn'] = 'Agrega una columna';
	$lang['strcolumnadded'] = 'Columna agregada.';
	$lang['strcolumnaddedbad'] = 'No s\'ha pogut agregar la columna.';
	$lang['strcascade'] = 'EN CASCADA';
	$lang['strtablealtered'] = 'Taula modificada.';
	$lang['strtablealteredbad'] = 'No s\'ha pogut modificar la columna.';
	$lang['strdataonly'] = 'Només dades';
	$lang['strstructureonly'] = 'Nomes estructura';
	$lang['strstructureanddata'] = 'Estructura i dades';
	$lang['strtabbed'] = 'Tabulat';
	$lang['strauto'] = 'Automàtic';
	$lang['strconfvacuumtable'] = 'Està segur de voler un vacuum "%s"?';
	$lang['strconfanalyzetable'] = 'Està segur de voler un analyze "%s"?';
        $lang['strconfreindextable']  =  'Està segur de voler un reindex "%s"?';
        $lang['strconfclustertable']  =  'Està sergur de voler un cluster "%s"?';
	$lang['strestimatedrowcount'] = 'Nombre estimat de files';
	$lang['strspecifytabletoanalyze'] = 'Ha d\'especificar almenys una taula per l\'analyze.';
	$lang['strspecifytabletoempty'] = 'Ha d\'especificar almenys una taula per buidar.';
	$lang['strspecifytabletodrop'] = 'Ha d\'especificar almenys una taula per eliminar.';
	$lang['strspecifytabletovacuum'] = 'Ha d\'especificar almenys una taula pel vacuum.';
        $lang['strspecifytabletoreindex']  =  'Ha d\'especifiar almenys una taula pel reindex.';
        $lang['strspecifytabletocluster']  =  'Ha d\'especificar almenys una taula pel cluster.';
        $lang['strnofieldsforinsert']  =  'No es pot insertar una fila a una taula sense cap columna.';

	// Columns
	$lang['strcolprop'] = 'Propietats de la Columna';
	$lang['strnotableprovided'] = 'No s\'ha proporcionat cap taula!';
		
	// Users
	$lang['struser'] = 'Usuari';
	$lang['strusers'] = 'Usuaris';
	$lang['strusername'] = 'Usuari';
	$lang['strpassword'] = 'Contrasenya';
	$lang['strsuper'] = 'Superusuari?';
	$lang['strcreatedb'] = 'Crear DB?';
	$lang['strexpires'] = 'Expira';
	$lang['strsessiondefaults'] = 'Valors predeterminats de la sessió';
	$lang['strnousers'] = 'No s\'han trobat usuaris.';
	$lang['struserupdated'] = 'Usuari actualitzat.';
	$lang['struserupdatedbad'] = 'L\'actualització de l\'usuari ha fallat.';
	$lang['strshowallusers'] = 'Mostra tots els usuaris';
	$lang['strcreateuser'] = 'Crea un usuari';
	$lang['struserneedsname'] = 'Ha de donar un nom a l\'usuari.';
	$lang['strusercreated'] = 'Usuari creat.';
	$lang['strusercreatedbad'] = 'Error al crear l\'usuari.';
	$lang['strconfdropuser'] = 'Està segur de voler eliminar l\'usuari "%s"?';
	$lang['struserdropped'] = 'Usuari eliminat.';
	$lang['struserdroppedbad'] = 'Error a l\'eliminar l\'usuari.';
	$lang['straccount'] = 'Compte';
	$lang['strchangepassword'] = 'Canvia la contrasenya';
	$lang['strpasswordchanged'] = 'Contrasenya canviada.';
	$lang['strpasswordchangedbad'] = 'Error al canviar la contrasenya.';
	$lang['strpasswordshort'] = 'Contrasenya massa curta.';
	$lang['strpasswordconfirm'] = 'La contrasenya no coincideix amb la confirmació.';
	
	// Groups
	$lang['strgroup'] = 'Grup';
	$lang['strgroups'] = 'Grups';
	$lang['strshowallgroups'] = 'Mostra tots els grups';
	$lang['strnogroup'] = 'Grup no trobat.';
	$lang['strnogroups'] = 'No s\'han trobat grups.';
	$lang['strcreategroup'] = 'Crea un grup';
	$lang['strgroupneedsname'] = 'Ha de donar un nom al grup.';
	$lang['strgroupcreated'] = 'Grup creat.';
	$lang['strgroupcreatedbad'] = 'No s\'ha pogut crear el grup.';	
	$lang['strconfdropgroup'] = 'Està segur de voler eliminar el grup "%s"?';
	$lang['strgroupdropped'] = 'Grup eliminat.';
	$lang['strgroupdroppedbad'] = 'No s\'ha pogut eliminar el grup.';
	$lang['strmembers'] = 'Membres';
	$lang['strmemberof'] = 'Membre de';
	$lang['stradminmembers'] = 'Membres administradors';
	$lang['straddmember'] = 'Afegeix un membre';
	$lang['strmemberadded'] = 'Membre afegit.';
	$lang['strmemberaddedbad'] = 'No s\'ha pogut afegir el membre.';
	$lang['strdropmember'] = 'Elimina el membre';
	$lang['strconfdropmember'] = 'Està segur de voler eliminar el membre "%s" del grup "%s"?';
	$lang['strmemberdropped'] = 'Membre eliminat.';
	$lang['strmemberdroppedbad'] = 'No s\'ha pogut eliminar el membre.';
	
	// Roles
	$lang['strrole'] = 'Rol';
	$lang['strroles'] = 'Rols';
	$lang['strshowallroles'] = 'Mostra tots els rols';
	$lang['strnoroles'] = 'No s\'han trobat rols.';
	$lang['strinheritsprivs'] = 'Hereda privilegis?';
	$lang['strcreaterole'] = 'Crea un rol';
	$lang['strcancreaterole'] = 'Crear el rol?';
	$lang['strrolecreated'] = 'Rol creat.';
	$lang['strrolecreatedbad'] = 'No s\'ha pogut crear el rol.';
	$lang['strrolealtered'] = 'Rol modificat.';
	$lang['strrolealteredbad'] = 'No s\ha pogut modificar el rol.';
	$lang['strcanlogin'] = 'Pot entrar?';
	$lang['strconnlimit'] = 'Límit de la connexió';
	$lang['strdroprole'] = 'Elimina el rol';
	$lang['strconfdroprole'] = 'Està segur de voler eliminar el rol \'%s\'?';
	$lang['strroledropped'] = 'Rol eliminat.';
	$lang['strroledroppedbad'] = 'No s\'ha pogut eliminar el rol.';
	$lang['strnolimit'] = 'Sense límit';
	$lang['strnever'] = 'Mai';
	$lang['strroleneedsname'] = 'Ha de donar un nom al rol.';

	// Privileges
	$lang['strprivilege'] = 'Privilegi';
	$lang['strprivileges'] = 'Privilegis';
	$lang['strnoprivileges'] = 'Aquest objecte té els privilegis predeterminats.';
	$lang['strgrant'] = 'Concedeix';
	$lang['strrevoke'] = 'Revoca';
	$lang['strgranted'] = 'Privilegis canviats.';
	$lang['strgrantfailed'] = 'Ha fallat el canvi de privilegis.';
	$lang['strgrantbad'] = 'Ha d\'especificar almenys un usuari o grup i almenys un privilegi.';
	$lang['strgrantor'] = 'Cedent';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Base de dades';
	$lang['strdatabases'] = 'Bases de dades';
	$lang['strshowalldatabases'] = 'Mostra totes les bases de dades';
	$lang['strnodatabases'] = 'No s\'han trobat bases de dades.';
	$lang['strcreatedatabase'] = 'Crea una base de dades';
	$lang['strdatabasename'] = 'Nom de la base de dades';
	$lang['strdatabaseneedsname'] = 'Ha de donar un nom a la base de dades.';
	$lang['strdatabasecreated'] = 'Base de dades creada.';
	$lang['strdatabasecreatedbad'] = 'No s\'ha pogut crear la base de dades.';
	$lang['strconfdropdatabase'] = 'Està segur de voler eliminar la base de dades "%s"?';
	$lang['strdatabasedropped'] = 'Base de dades eliminada.';
	$lang['strdatabasedroppedbad'] = 'No s\'ha pogut eliminar la base de dades.';
	$lang['strentersql'] = 'Entri la sentència SQL per executar a sota:';
	$lang['strsqlexecuted'] = 'SQL executat.';
	$lang['strvacuumgood'] = 'Vacuum completat.';
	$lang['strvacuumbad'] = 'Vacuum ha fallat.';
	$lang['stranalyzegood'] = 'Analyze completat.';
	$lang['stranalyzebad'] = 'Analyze ha fallat.';
	$lang['strreindexgood'] = 'Reindex completat.';
	$lang['strreindexbad'] = 'Reindex ha fallat.';
	$lang['strfull'] = 'Ple';
	$lang['strfreeze'] = 'Congelat';
	$lang['strforce'] = 'Força';
	$lang['strsignalsent'] = 'Senyal enviat.';
	$lang['strsignalsentbad'] = 'L\'enviament del senyal ha fallat.';
	$lang['strallobjects'] = 'Tots els objectes';
	$lang['strdatabasealtered'] = 'Base de dades modificada.';
	$lang['strdatabasealteredbad'] = 'No s\'ha pogut modificar la base de dades.';
	$lang['strspecifydatabasetodrop'] = 'Ha d\'especificar almenys una base de dades per eliminar.';
        $lang['strtemplatedb']  =  'Plantilla';
        $lang['strconfanalyzedatabase']  =  'Està segur de voler un analyze de totes les taules de la base de dades "%s"?';
        $lang['strconfvacuumdatabase']  =  'Està segur de voler un vacuum de totes les taules de la base de dades "%s"?';
        $lang['strconfreindexdatabase']  =  'Està segur de voler un reindex de totes les taules de la base de dades "%s"?';
        $lang['strconfclusterdatabase']  =  'Està segur de voler un clúster de totes les taules de la base de dades "%s"?';

	// Views
	$lang['strview'] = 'Vista';
	$lang['strviews'] = 'Vistes';
	$lang['strshowallviews'] = 'Mostra totes les vistes';
	$lang['strnoview'] = 'No s\'ha trobat la vista.';
	$lang['strnoviews'] = 'No s\'han trobat vistes.';
	$lang['strcreateview'] = 'Crea una vista';
	$lang['strviewname'] = 'Nom de la vista';
	$lang['strviewneedsname'] = 'Ha d\'anomenar la vista.';
	$lang['strviewneedsdef'] = 'Ha de donar una definició a la vista.';
	$lang['strviewneedsfields'] = 'Ha de seleccionar les columnes de la vista.';
	$lang['strviewcreated'] = 'Vista creada.';
	$lang['strviewcreatedbad'] = 'No s\'ha pogut crear la vista.';
	$lang['strconfdropview'] = 'Està segur de voler eliminar la vista "%s"?';
	$lang['strviewdropped'] = 'Vista eliminada.';
	$lang['strviewdroppedbad'] = 'No s\'ha pogut eliminar la vista.';
	$lang['strviewupdated'] = 'Vista actualitzada.';
	$lang['strviewupdatedbad'] = 'No s\'ha pogut actualitzar la vista.';
	$lang['strviewlink'] = 'Enllaçant claus';
	$lang['strviewconditions'] = 'Condicions addicionals';
	$lang['strcreateviewwiz'] = 'Crea una vista amb l\'assistent';
	$lang['strrenamedupfields'] = 'Reanomena els camps duplicats';
	$lang['strdropdupfields'] = 'Elimina els camps duplicats';
	$lang['strerrordupfields'] = 'Error en els camps duplicats';
	$lang['strviewaltered'] = 'Vista modificada.';
	$lang['strviewalteredbad'] = 'No s\'ha pogut modificar la vista.';
	$lang['strspecifyviewtodrop'] = 'Ha d\'especificar almenys una vista per eliminar.';

	// Sequences
	$lang['strsequence'] = 'Seqüència';
	$lang['strsequences'] = 'Seqüències';
	$lang['strshowallsequences'] = 'Mostra totes les seqüències';
	$lang['strnosequence'] = 'No s\'ha trobat la seqüencia.';
	$lang['strnosequences'] = 'No s\'han trobat seqüencies.';
	$lang['strcreatesequence'] = 'Crea una seqüència';
	$lang['strlastvalue'] = 'Últim valor';
	$lang['strincrementby'] = 'Incrementar en';	
	$lang['strstartvalue'] = 'Valor inicial';
        $lang['strrestartvalue']  =  'Valor al reiniciar';
	$lang['strmaxvalue'] = 'Valor màxim';
	$lang['strminvalue'] = 'Valor mínim';
	$lang['strcachevalue'] = 'Valor de cache';
	$lang['strlogcount'] = 'Compte del registre';
	$lang['strcancycle'] = 'Pot completar un cicle?';
	$lang['striscalled'] = 'Vol incrementar l\últim valor abans de retornar el següent valor (is_called)?';
	$lang['strsequenceneedsname'] = 'Ha d\'especificar un nom per la seqüència.';
	$lang['strsequencecreated'] = 'Seqüència creada.';
	$lang['strsequencecreatedbad'] = 'No s\'ha pogut crear la seqüència.'; 
	$lang['strconfdropsequence'] = 'Està segur de voler eliminar la seqüència "%s"?';
	$lang['strsequencedropped'] = 'Seqüència eliminada.';
	$lang['strsequencedroppedbad'] = 'No s\'ha pogut eliminar la seqüència.';
        $lang['strsequencerestart']  =  'Seqüència reiniciada.';
        $lang['strsequencerestartbad']  =  'No s\'ha pogut reiniciar la seqüència.';
	$lang['strsequencereset'] = 'Seqüència reiniciada.';
	$lang['strsequenceresetbad'] = 'No s\'ha pogut reiniciar la seqüència.'; 
 	$lang['strsequencealtered'] = 'Seqüència modificada.';
 	$lang['strsequencealteredbad'] = 'No s\'ha pogut modificar la seqüència.';
 	$lang['strsetval'] = 'Fixa el valor';
 	$lang['strsequencesetval'] = 'Valor de la seqüència fixat.';
 	$lang['strsequencesetvalbad'] = 'No s\'ha pogut fixar el valor de la seqüencia.';
 	$lang['strnextval'] = 'Valor incremental';
 	$lang['strsequencenextval'] = 'Seqüència incrementada.';
 	$lang['strsequencenextvalbad'] = 'No s\'ha pogut incrementar la seqüència.';
	$lang['strspecifysequencetodrop'] = 'Ha d\'especificar almenys una seqüència per eliminar.';

	// Indexes
	$lang['strindex'] = 'Índex';
	$lang['strindexes'] = 'Índexs';
	$lang['strindexname'] = 'Nom de l\'índex';
	$lang['strshowallindexes'] = 'Mostra tots els índexs';
	$lang['strnoindex'] = 'No s\'ha trobat l\'índex';
	$lang['strnoindexes'] = 'No s\'han trobat índexs.';
	$lang['strcreateindex'] = 'Crea un índex';
	$lang['strtabname'] = 'Nom de la pestanya';
	$lang['strcolumnname'] = 'Nom de la columna';
	$lang['strindexneedsname'] = 'Ha d\'anomenar l\'índex.';
	$lang['strindexneedscols'] = 'Els índexs requereixen un número vàlid de columnes.';
	$lang['strindexcreated'] = 'Índex creat';
	$lang['strindexcreatedbad'] = 'No s\'ha pogut crear l\'índex.';
	$lang['strconfdropindex'] = 'Està segur de voler eliminar l\'índex "%s"?';
	$lang['strindexdropped'] = 'Índex eliminat.';
	$lang['strindexdroppedbad'] = 'No s\'ha pogut eliminar l\'índex.';
	$lang['strkeyname'] = 'Nom de la clau';
	$lang['struniquekey'] = 'Clau única';
	$lang['strprimarykey'] = 'Clau primària';
 	$lang['strindextype'] = 'Tipus d\'índex';
	$lang['strtablecolumnlist'] = 'Columnes a la taula';
	$lang['strindexcolumnlist'] = 'Columnes a l\'índex';
	$lang['strclusteredgood'] = 'Clúster completat.';
	$lang['strclusteredbad'] = 'No s\'ha pogut crear el clúster.';
        $lang['strconcurrently']  =  'Actualment';
        $lang['strnoclusteravailable']  =  'No hi ha el clúster disponible en l\'índex.';

	// Rules
	$lang['strrules'] = 'Regles';
	$lang['strrule'] = 'Regla';
	$lang['strshowallrules'] = 'Mostra totes les regles';
	$lang['strnorule'] = 'No s\'ha trobat la regla.';
	$lang['strnorules'] = 'No s\'han trobat regles.';
	$lang['strcreaterule'] = 'Crea una regla';
	$lang['strrulename'] = 'Nom de la regla';
	$lang['strruleneedsname'] = 'Ha d\'especificar un nom per la regla';
	$lang['strrulecreated'] = 'Regla creada.';
	$lang['strrulecreatedbad'] = 'No s\'ha pogut crear la regla.';
	$lang['strconfdroprule'] = 'Està segur de voler eliminar la regla "%s" a "%s"?';
	$lang['strruledropped'] = 'Regla eliminada.';
	$lang['strruledroppedbad'] = 'No s\'ha pogut eliminar la regla.';

	// Constraints
	$lang['strconstraint'] = 'Restricció';
	$lang['strconstraints'] = 'Restriccions';
	$lang['strshowallconstraints'] = 'Mostra totes les restriccions';
	$lang['strnoconstraints'] = 'No s\'han trobat restriccions.';
	$lang['strcreateconstraint'] = 'Crea una restricció';
	$lang['strconstraintcreated'] = 'Restricció creada.';
	$lang['strconstraintcreatedbad'] = 'No s\'ha pogut crear la restricció.';
	$lang['strconfdropconstraint'] = 'Està segur de voler eliminar la restricció "%s" de "%s"?';
	$lang['strconstraintdropped'] = 'Restricció eliminada.';
	$lang['strconstraintdroppedbad'] = 'No s\'ha pogut eliminar la restricció.';
	$lang['straddcheck'] = 'Agrega un control';
	$lang['strcheckneedsdefinition'] = 'La restricció de control necessita una definició.';
	$lang['strcheckadded'] = 'Restricció de control agregada.';
	$lang['strcheckaddedbad'] = 'No s\'ha pogut agregar la restricció de control.';
	$lang['straddpk'] = 'Agrega una clau primària';
	$lang['strpkneedscols'] = 'La clau primària requereix almenys una columna.';
	$lang['strpkadded'] = 'Clau primària agregada.';
	$lang['strpkaddedbad'] = 'No s\'ha pogut agregar la clau primària.';
	$lang['stradduniq'] = 'Agrega una clau única';
	$lang['struniqneedscols'] = 'La clau única requereix almenys una columna.';
	$lang['struniqadded'] = 'Clau única agregada.';
	$lang['struniqaddedbad'] = 'No s\'ha pogut agregar la clau única.';
	$lang['straddfk'] = 'Agrega una clau externa';
	$lang['strfkneedscols'] = 'La clau externa requereix almenys una columna.';
	$lang['strfkneedstarget'] = 'La clau externa requereix una taula de referència.';
	$lang['strfkadded'] = 'Clau externa agregada.';
	$lang['strfkaddedbad'] = 'No s\'ha pogut agregar la clau externa.';
	$lang['strfktarget'] = 'Taula de destí';
	$lang['strfkcolumnlist'] = 'Columnes a la clau';
	$lang['strondelete'] = 'A L\'ELIMINAR';
	$lang['stronupdate'] = 'A L\'ACTUALITZAR';

	// Functions
	$lang['strfunction'] = 'Funció';
	$lang['strfunctions'] = 'Funcions';
	$lang['strshowallfunctions'] = 'Mostra totes les funcions';
	$lang['strnofunction'] = 'No s\'ha trobat la funció.';
	$lang['strnofunctions'] = 'No s\'han trobat funcions';
	$lang['strcreateplfunction'] = 'Crea una funció SQL/PL';
	$lang['strcreateinternalfunction'] = 'Crea una funció interna';
	$lang['strcreatecfunction'] = 'Crea una funció C';
	$lang['strfunctionname'] = 'Nom de la funció';
	$lang['strreturns'] = 'Retorna';
	$lang['strproglanguage'] = 'Llenguatge de programació';
	$lang['strfunctionneedsname'] = 'Ha de donar un nom a la funció.';
	$lang['strfunctionneedsdef'] = 'Ha de donar una definició a la funció.';
	$lang['strfunctioncreated'] = 'Funció creada.';
	$lang['strfunctioncreatedbad'] = 'No s\'ha pogut crear la funció.';
	$lang['strconfdropfunction'] = 'Està segur de voler eliminar la funció "%s"?';
	$lang['strfunctiondropped'] = 'Funció eliminada.';
	$lang['strfunctiondroppedbad'] = 'No s\'ha pogut eliminar la funció.';
	$lang['strfunctionupdated'] = 'Funció actualitzada.';
	$lang['strfunctionupdatedbad'] = 'No s\'ha pogut actualitzar la funció.';
	$lang['strobjectfile'] = 'Fitxer objecte';
	$lang['strlinksymbol'] = 'Enllaç simbòlic';
	$lang['strarguments'] = 'Arguments';
	$lang['strargmode'] = 'Mode';
	$lang['strargtype'] = 'Tipus';
	$lang['strargadd'] = 'Afegeix un altre argument';
	$lang['strargremove'] = 'Elimina aquest argument';
	$lang['strargnoargs'] = 'Aquesta funció no tindrà arguments.';
	$lang['strargenableargs'] = 'Habilita els arguments passats a aquesta funció.';
	$lang['strargnorowabove'] = 'Hi ha d\'haver una fila sobre aquesta fila.';
	$lang['strargnorowbelow'] = 'Hi ha d\'haver una fila sota aquesta fila.';
	$lang['strargraise'] = 'Mou amunt.';
	$lang['strarglower'] = 'Mou avall.';
	$lang['strargremoveconfirm'] = 'Està segur de voler eliminar aquest argument? Això NO es pot desfer.';
	$lang['strfunctioncosting'] = 'Funció de Cost';
	$lang['strresultrows'] = 'Files Resultants';
	$lang['strexecutioncost'] = 'Cost de l\'Execució';
	$lang['strspecifyfunctiontodrop'] = 'Ha d\'especificar almenys una funció per eliminar.';

	// Triggers
	$lang['strtrigger'] = 'Disparador';
	$lang['strtriggers'] = 'Disparadors';
	$lang['strshowalltriggers'] = 'Mostrar tots els disparadors';
	$lang['strnotrigger'] = 'No s\'ha trobat el disparador.';
	$lang['strnotriggers'] = 'No s\'han trobat disparadors.';
	$lang['strcreatetrigger'] = 'Crea un disparador';
	$lang['strtriggerneedsname'] = 'Ha de donar un nom al disparador.';
	$lang['strtriggerneedsfunc'] = 'Ha d\'especificar una funció pel disparador.';
	$lang['strtriggercreated'] = 'Disparador creat.';
	$lang['strtriggercreatedbad'] = 'No s\'ha pogut crear el disparador.';
	$lang['strconfdroptrigger'] = 'Està segur de voler eliminar el disparador "%s" de "%s"?';
	$lang['strconfenabletrigger'] = 'Està segur de voler habilitar el disparador "%s" a "%s"?';
	$lang['strconfdisabletrigger'] = 'Està segur de voler inhabilitar el disparador "%s" a "%s"?';
	$lang['strtriggerdropped'] = 'Disparador eliminat.';
	$lang['strtriggerdroppedbad'] = 'No s\'ha pogut eliminar el disparador.';
	$lang['strtriggerenabled'] = 'Disparador habilitat.';
	$lang['strtriggerenabledbad'] = 'No s\'ha pogut habilitar el disparador.';
	$lang['strtriggerdisabled'] = 'Disparador inhabilitat.';
	$lang['strtriggerdisabledbad'] = 'No s\'ha pogut inhabilitar el disparador.';
	$lang['strtriggeraltered'] = 'Disparador modificat.';
	$lang['strtriggeralteredbad'] = 'No s\'ha pogut modificar el disparador.';
	$lang['strforeach'] = 'Per cada';

	// Types
	$lang['strtype'] = 'Tipus';
	$lang['strtypes'] = 'Tipus';
	$lang['strshowalltypes'] = 'Mostrar tots els tipus';
	$lang['strnotype'] = 'No s\'ha trobat el tipus.';
	$lang['strnotypes'] = 'No s\'han trobat els tipus.';
	$lang['strcreatetype'] = 'Crea un tipus';
	$lang['strcreatecomptype'] = 'Crea un tipus compost';
	$lang['strcreateenumtype'] = 'Crea un tipus d\'enumeració';
	$lang['strtypeneedsfield'] = 'Ha d\'especificar almenys un camp.';
	$lang['strtypeneedsvalue'] = 'Ha d\'especificar almenys un valor.';
	$lang['strtypeneedscols'] = 'Ha d\'especificar un número vàlid de camps.';	
	$lang['strtypeneedsvals'] = 'Ha d\'especificar un número vàlid de valors.';
	$lang['strinputfn'] = 'Funció d\'entrada';
	$lang['stroutputfn'] = 'Funció de sortida';
	$lang['strpassbyval'] = 'Passat per valor?';
	$lang['stralignment'] = 'Alineament';
	$lang['strelement'] = 'Element';
	$lang['strdelimiter'] = 'Delimitador';
	$lang['strstorage'] = 'Emmagatzemament';
	$lang['strfield'] = 'Camp';
	$lang['strnumfields'] = 'Num. de camps';
	$lang['strnumvalues'] = 'Num. de valors';
	$lang['strtypeneedsname'] = 'Ha de donar un nom al tipus.';
	$lang['strtypeneedslen'] = 'Ha de donar una longitud al tipus.';
	$lang['strtypecreated'] = 'Tipus creat';
	$lang['strtypecreatedbad'] = 'No s\'ha pogut crear el tipus.';
	$lang['strconfdroptype'] = 'Està segur de voler eliminar el tipus "%s"?';
	$lang['strtypedropped'] = 'Tipus eliminat.';
	$lang['strtypedroppedbad'] = 'No s\'ha pogut eliminar el tipus.';
	$lang['strflavor'] = 'Varietat';
	$lang['strbasetype'] = 'Base';
	$lang['strcompositetype'] = 'Compost';
	$lang['strpseudotype'] = 'Pseudo';
	$lang['strenum'] = 'Enumeració';
	$lang['strenumvalues'] = 'Valors de l\'enumeració';

	// Schemas
	$lang['strschema'] = 'Esquema';
	$lang['strschemas'] = 'Esquemes';
	$lang['strshowallschemas'] = 'Mostra tots els esquemes';
	$lang['strnoschema'] = 'No s\'ha trobat l\'esquema.';
	$lang['strnoschemas'] = 'No s\'han trobat esquemes.';
	$lang['strcreateschema'] = 'Crea un esquema';
	$lang['strschemaname'] = 'Nom de l\'esquema';
	$lang['strschemaneedsname'] = 'Ha d\'anomenar l\'esquema.';
	$lang['strschemacreated'] = 'Esquema creat';
	$lang['strschemacreatedbad'] = 'No s\'ha pogut crear l\'esquema.';
	$lang['strconfdropschema'] = 'Està segur de voler eliminar l\'esquema "%s"?';
	$lang['strschemadropped'] = 'Esquema eliminat.';
	$lang['strschemadroppedbad'] = 'No s\'ha pogut eliminar l\'esquema.';
	$lang['strschemaaltered'] = 'Esquema modificat.';
	$lang['strschemaalteredbad'] = 'No s\'ha pogut modificar l\'esquema.';
	$lang['strsearchpath'] = 'Camí de cerca de l\'esquema';
	$lang['strspecifyschematodrop'] = 'Ha d\especificar almenys un esquema per eliminar.';

	// Reports

	// Domains
	$lang['strdomain'] = 'Domini';
	$lang['strdomains'] = 'Dominis';
	$lang['strshowalldomains'] = 'Mostrar tots els dominis';
	$lang['strnodomains'] = 'No s\'han trobat dominis.';
	$lang['strcreatedomain'] = 'Crea un domini';
	$lang['strdomaindropped'] = 'Domini eliminat.';
	$lang['strdomaindroppedbad'] = 'No s\'ha pogut eliminar el domini.';
	$lang['strconfdropdomain'] = 'Està segur de voler eliminar el domini "%s"?';
	$lang['strdomainneedsname'] = 'Ha d\'anomenar el domini.';
	$lang['strdomaincreated'] = 'Domini creat.';
	$lang['strdomaincreatedbad'] = 'No s\'ha pogut crear el domini.';	
	$lang['strdomainaltered'] = 'Domini modificat.';
	$lang['strdomainalteredbad'] = 'No s\'ha pogut modificar el domini.';	

	// Operators
	$lang['stroperator'] = 'Operador';
	$lang['stroperators'] = 'Operadors';
	$lang['strshowalloperators'] = 'Mostra tots els operadors';
	$lang['strnooperator'] = 'No s\'ha trobat l\'operador.';
	$lang['strnooperators'] = 'No s\'han trobat operadors.';
	$lang['strcreateoperator'] = 'Crea un operador';
	$lang['strleftarg'] = 'Tipus de l\'arg. esquerre';
	$lang['strrightarg'] = 'Tipus de l\'arg. dret';
	$lang['strcommutator'] = 'Commutador';
	$lang['strnegator'] = 'Negació';
	$lang['strrestrict'] = 'Restringeix';
	$lang['strjoin'] = 'Unieix';
	$lang['strhashes'] = 'Hash';
	$lang['strmerges'] = 'Fussiona';
	$lang['strleftsort'] = 'Sort esquerre';
	$lang['strrightsort'] = 'Sort dret';
	$lang['strlessthan'] = 'Menor que';
	$lang['strgreaterthan'] = 'Major que';
	$lang['stroperatorneedsname'] = 'Ha d\'anomenar l\'operador.';
	$lang['stroperatorcreated'] = 'Operador creat';
	$lang['stroperatorcreatedbad'] = 'No s\'ha pogut crear l\'operador.';
	$lang['strconfdropoperator'] = 'Està segur de voler eliminar l\'operador "%s"?';
	$lang['stroperatordropped'] = 'Operador eliminat.';
	$lang['stroperatordroppedbad'] = 'No s\'ha pogut eliminar l\'operador.';

	// Casts
	$lang['strcasts'] = 'Conversió de tipus';
	$lang['strnocasts'] = 'No s\'han trobat conversions.';
	$lang['strsourcetype'] = 'Tipus inicial';
	$lang['strtargettype'] = 'Tipus final';
	$lang['strimplicit'] = 'Implícit';
	$lang['strinassignment'] = 'En assignació';
	$lang['strbinarycompat'] = '(Compatible amb binari)';
	
	// Conversions
	$lang['strconversions'] = 'Conversions';
	$lang['strnoconversions'] = 'No s\'han trobat conversions.';
	$lang['strsourceencoding'] = 'Codificació inicial';
	$lang['strtargetencoding'] = 'Codificació final';
	
	// Languages
	$lang['strlanguages'] = 'Llenguatges';
	$lang['strnolanguages'] = 'No s\'han trobat llenguatges.';
	$lang['strtrusted'] = 'Fiable';
	
	// Info
	$lang['strnoinfo'] = 'No hi ha informació disponible.';
	$lang['strreferringtables'] = 'Referent a les taules';
	$lang['strparenttables'] = 'Taules pare';
	$lang['strchildtables'] = 'Taules fill';
	
	// Aggregates
	$lang['straggregate'] = 'Agregat';
	$lang['straggregates'] = 'Agregats';
	$lang['strnoaggregates'] = 'No s\'han trobat agregats';
	$lang['stralltypes'] = '(Tots els tipus)';
	$lang['strcreateaggregate'] = 'Crea un agregat';
	$lang['straggrbasetype'] = 'Tipus de dades d\'entrada';
	$lang['straggrsfunc'] = 'Funció de la transició de l\'estat';
	$lang['straggrstype'] = 'Tipus de dades pel valor de l\'estat';
	$lang['straggrffunc'] = 'Funció final';
	$lang['straggrinitcond'] = 'Condició inicial';
	$lang['straggrsortop'] = 'Operador ordre';
	$lang['strconfdropaggregate'] = 'Està segur de voler elimnar l\'agregat \'%s\'?';
	$lang['straggregatedropped'] = 'Agregat eliminat.';
	$lang['straggregatedroppedbad'] = 'No s\'ha pogut eliminar l\'agregat.';
	$lang['straggraltered'] = 'Agregat modificat.';
	$lang['straggralteredbad'] = 'No s\'ha pogut modificar l\'agregat.';
	$lang['straggrneedsname'] = 'Ha d\'especificar un nom per l\'agregat';
	$lang['straggrneedsbasetype'] = 'Ha d\'especificar el tipus de dades d\'entrada per l\'agregat';
	$lang['straggrneedssfunc'] = 'Ha d\'especificar el nom de la funció de transició de l\'estat per l\'agregat';
	$lang['straggrneedsstype'] = 'Ha d\'especificar el tipus de dades pel valor de l\'estat de l\'agregat';
	$lang['straggrcreated'] = 'Agregat creat.';
	$lang['straggrcreatedbad'] = 'No s\'ha pogut crear l\agregat.';
	$lang['straggrshowall'] = 'Mostra tots els agregats';

	// Operator Classes
	$lang['stropclasses'] = 'Classes d\'operadors';
	$lang['strnoopclasses'] = 'No s\'han trobat classes d\'operadors.';
	$lang['straccessmethod'] = 'Mètode d\'accés';

	// Stats and performance
	$lang['strrowperf'] = 'Row Performance';
	$lang['strioperf'] = 'I/O Performance';
	$lang['stridxrowperf'] = 'Index Row Performance';
	$lang['stridxioperf'] = 'Index I/O Performance';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Sequential';
	$lang['strscan'] = 'Scan';
	$lang['strread'] = 'Read';
	$lang['strfetch'] = 'Fetch';
	$lang['strheap'] = 'Heap';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST Index';
	$lang['strcache'] = 'Cache';
	$lang['strdisk'] = 'Disk';
	$lang['strrows2'] = 'Rows';

	// Tablespaces
	$lang['strtablespace'] = 'Tablespace';
	$lang['strtablespaces'] = 'Tablespaces';
	$lang['strshowalltablespaces'] = 'Mostrar tots els tablespaces';
	$lang['strnotablespaces'] = 'No s\'han trobat tablespaces';
	$lang['strcreatetablespace'] = 'Crea un tablespace';
	$lang['strlocation'] = 'Localització';
	$lang['strtablespaceneedsname'] = 'Ha de donar un nom al tablespace.';
	$lang['strtablespaceneedsloc'] = 'Ha de donar un directori on crear el tablespace.';
	$lang['strtablespacecreated'] = 'Tablespace creat.';
	$lang['strtablespacecreatedbad'] = 'No s\'ha pogut crear el Tablespace.';
	$lang['strconfdroptablespace'] = 'Està segur de voler eliminar el tablespace "%s"?';
	$lang['strtablespacedropped'] = 'Tablespace eliminat.';
	$lang['strtablespacedroppedbad'] = 'No s\'ha pogut eliminar el tablespace.';
	$lang['strtablespacealtered'] = 'Tablespace modificat.';
	$lang['strtablespacealteredbad'] = 'No s\'ha pogut modifcar el tablespace.';
	
	// Miscellaneous
	$lang['strtopbar'] = '%s corrent a %s:%s -- Ha entrat com a usuari "%s"';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strhelp'] = 'Ajuda';
	$lang['strhelpicon'] = '?';
	$lang['strhelppagebrowser'] = 'Cercador de pàgines d\'ajuda';
	$lang['strselecthelppage'] = 'Selecciona una pàgina d\'ajuda';
	$lang['strinvalidhelppage'] = 'Pàgina d\'ajuda invàlida.';
	$lang['strlogintitle'] = 'Entrar a %s';
	$lang['strlogoutmsg'] = 'Sortir de %s';
	$lang['strloading'] = 'Carregant...';
	$lang['strerrorloading'] = 'Error Carregant';
	$lang['strclicktoreload'] = 'Clicar per recarregar';

	// Autovacuum
	$lang['strautovacuum'] = 'Autovacuum'; 
	$lang['strturnedon'] = 'Activat'; 
	$lang['strturnedoff'] = 'Desactivat'; 
	$lang['strenabled'] = 'Habilitat'; 
        $lang['strnovacuumconf']  =  'No s\'ha trobat la configuració de l\'autovacuum.';
	$lang['strvacuumbasethreshold'] = 'Llindar Base del Vacuum'; 
	$lang['strvacuumscalefactor'] = 'Factor d\'Escala del Vacuum';  
	$lang['stranalybasethreshold'] = 'Llindar Base de l\'Analyze';  
	$lang['stranalyzescalefactor'] = 'Factor d\'Escala de l\'Analyze'; 
	$lang['strvacuumcostdelay'] = 'Cost del Retard del Vacuum'; 
	$lang['strvacuumcostlimit'] = 'Límit de Cost del Vacuum';  
        $lang['strvacuumpertable']  =  'Configuració de l\'autovacuum per taula';
        $lang['straddvacuumtable']  =  'Afegeix la configuració de l\'autovacuum per una taula';
        $lang['streditvacuumtable']  =  'Edita la configuració de l\'autovacuum de la taula %s';
        $lang['strdelvacuumtable']  =  'Vol eliminar la configuració de l\'autovacuum de la taula %s ?';
        $lang['strvacuumtablereset']  =  'S\'ha inicialitzat la configuració de l\'autovacuum de la taula %s als valors per defecte';
        $lang['strdelvacuumtablefail']  =  'No s\'ha pogut eliminar la configuració de l\'autovacuum de la taula %s';
        $lang['strsetvacuumtablesaved']  =  'Configuració de l\'autovacuum de la taula %s desada.';
        $lang['strsetvacuumtablefail']  =  'Ha fallat la configuració de l\'autovacuum de la taula %s.';
        $lang['strspecifydelvacuumtable']  =  'Ha d\'especificar la taula d\'on vol eliminar els paràmetres de l\'autovacuum.';
        $lang['strspecifyeditvacuumtable']  =  'Ha d\'especificar la taula d\'on vol editar els paràmetres de l\'autovacuum.';
        $lang['strnotdefaultinred']  =  'Els paràmetres no per defecte en vermell.';

	// Table-level Locks
	$lang['strlocks'] = 'Bloquejos';
	$lang['strtransaction'] = 'ID de la Transacció';
	$lang['strvirtualtransaction'] = 'ID de la Transacció Virtual';
	$lang['strprocessid'] = 'ID del Procés';
	$lang['strmode'] = 'Mode de Bloqueig';
	$lang['strislockheld'] = 'S\'aguanta el bloqueig?';

	// Prepared transactions
	$lang['strpreparedxacts'] = 'Transaccions preparades';
	$lang['strxactid'] = 'ID de la Transacció';
	$lang['strgid'] = 'ID Global';
	
	// Fulltext search
	$lang['strfulltext'] = 'Cerca del Text Completa (FTS)';
	$lang['strftsconfig'] = 'Configuració FTS';
	$lang['strftsconfigs'] = 'Configuracions';
	$lang['strftscreateconfig'] = 'Crea una configuració FTS';
	$lang['strftscreatedict'] = 'Crea un diccionari';
	$lang['strftscreatedicttemplate'] = 'Crea una plantilla d\'un diccionari';
	$lang['strftscreateparser'] = 'Crea un analitzador';
	$lang['strftsnoconfigs'] = 'No s\'ha trobat cap configuració FTS.';
	$lang['strftsconfigdropped'] = 'Configuració FTS eliminada.';
	$lang['strftsconfigdroppedbad'] = 'No s\'ha pogut eliminar la configuració FTS.';
	$lang['strconfdropftsconfig'] = 'Està segur de voler eliminar la configuració FTS "%s"?';
	$lang['strconfdropftsdict'] = 'Està segur de voler eliminar el diccionari FTS "%s"?';
	$lang['strconfdropftsmapping'] = 'Està segur de voler eliminar el traçat "%s" de la configuració FTS "%s"?';
	$lang['strftstemplate'] = 'Plantilla';
	$lang['strftsparser'] = 'Analitzador';
	$lang['strftsconfigneedsname'] = 'Ha de donar un nom a la configuració FTS.';
	$lang['strftsconfigcreated'] = 'Configuració FTS creada.';
	$lang['strftsconfigcreatedbad'] = 'No s\'ha pogut crear la configuració FTS.';
	$lang['strftsmapping'] = 'Traçat';
	$lang['strftsdicts'] = 'Diccionaris';
	$lang['strftsdict'] = 'Diccionari';
	$lang['strftsemptymap'] = 'Mapa de la configuració FTS buida.';
	$lang['strftsconfigaltered'] = 'Configuració FTS modificada.';
	$lang['strftsconfigalteredbad'] = 'No s\'ha pogut modificar la configuració FTS.';
	$lang['strftsconfigmap'] = 'Mapa de la configuració FTS';
	$lang['strftsparsers'] = 'Analitzadors FTS';
	$lang['strftsnoparsers'] = 'No hi ha analitzadors FTS disponibles.';
	$lang['strftsnodicts'] = 'No hi ha diccionaris FTS disponibles.';
	$lang['strftsdictcreated'] = 'Diccionari FTS creat.';
	$lang['strftsdictcreatedbad'] = 'No s\ha pogut crear el diccionari FTS.';
	$lang['strftslexize'] = 'Lexize';
	$lang['strftsinit'] = 'Inicialitzador';
	$lang['strftsoptionsvalues'] = 'Opcions i valors';
	$lang['strftsdictneedsname'] = 'Ha de donar un nom al diccionari FTS.';
	$lang['strftsdictdropped'] = 'Diccionari FTS eliminat.';
	$lang['strftsdictdroppedbad'] = 'No s\'ha pogut eliminar el diccionari FTS.';
	$lang['strftsdictaltered'] = 'Diccionari FTS modificat.';
	$lang['strftsdictalteredbad'] = 'No s\'ha pogut modificar el diccionari FTS.';
	$lang['strftsaddmapping'] = 'Afegeix un nou traçat';
	$lang['strftsspecifymappingtodrop'] = 'Ha d\'especificar almenys un traçat per eliminar.';
	$lang['strftsspecifyconfigtoalter'] = 'Ha d\'especificar la configuració FTS per modificar';
	$lang['strftsmappingdropped'] = 'Traçat FTS eliminat.';
	$lang['strftsmappingdroppedbad'] = 'No s\'ha pogut eliminar el traçat FTS.';
	$lang['strftsnodictionaries'] = 'No s\'han trobat diccionaris.';
	$lang['strftsmappingaltered'] = 'Traçat FTS modificat.';
	$lang['strftsmappingalteredbad'] = 'No s\'ha pogut modificar el traçat FTS.';
	$lang['strftsmappingadded'] = 'Traçat FTS afegit.';
	$lang['strftsmappingaddedbad'] = 'No s\'ha pogut afegir el traçat FTS.';
	$lang['strftstabconfigs'] = 'Configuracions';
	$lang['strftstabdicts'] = 'Diccionaris';
	$lang['strftstabparsers'] = 'Analitzadors';
	$lang['strftscantparsercopy'] = 'No es pot especificar alhora un analitzador i una plantilla durant la creació de la configuració de la cerca de text.';
?>
