<?php

	/*
	 * Greek language file for phpPgAdmin.
	 *
	 * $Id: greek.php,v 0.5 June 2009, Adamantios Diamantidis Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Ελληνικά';
	$lang['applocale'] = 'el-GR';
	$lang['applangdir'] = 'ltr';

	// Welcome  
	$lang['strintro'] = 'Καλώς ήρθατε στο phpPgAdmin.';
	$lang['strppahome'] = 'Αρχική σελίδα phpPgAdmin';
	$lang['strpgsqlhome'] = 'Αρχική σελίδα PostgreSQL';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'Εγχειρίδια PostgreSQL (τοπικό αντίγραφο)';
	$lang['strreportbug'] = 'Αναφορά ελαττώματος στο phpPgAdmin';
	$lang['strviewfaq'] = 'Συχνές ερωτήσεις (FAQ)';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
	
	// Basic strings
	$lang['strlogin'] = 'Είσοδος';
	$lang['strloginfailed'] = 'Αποτυχία εισόδου';
	$lang['strlogindisallowed'] = 'Η είσοδος δεν επιτρέπεται για λόγους ασφαλείας.';
	$lang['strserver'] = 'Διακομιστής';
	$lang['strservers'] = 'Διακομιστές';
	$lang['strintroduction'] = 'Αρχική';
	$lang['strhost'] = 'Κόμβος';
	$lang['strport'] = 'Θύρα';
	$lang['strlogout'] = 'Εξοδος';
	$lang['strowner'] = 'Κάτοχος';
	$lang['straction'] = 'Πράξη';
	$lang['stractions'] = 'Ενέργειες';
	$lang['strname'] = 'Ονομα';
	$lang['strdefinition'] = 'Ορισμός';
	$lang['strproperties'] = 'Ιδιότητες';
	$lang['strbrowse'] = 'Προβολή';
	$lang['strenable'] = 'Ενεργοποίηση';
	$lang['strdisable'] = 'Απενεργοποίηση';
	$lang['strdrop'] = 'Διαγραφή';
	$lang['strdropped'] = 'Διαγράφηκε';
	$lang['strnull'] = 'Κενό';
	$lang['strnotnull'] = 'Να μην είναι κενό';
	$lang['strprev'] = '< Προηγούμενη';
	$lang['strnext'] = 'Επόμενη >';
	$lang['strfirst'] = '<< Πρώτη';
	$lang['strlast'] = 'Τελευταία >>';
	$lang['strfailed'] = 'Απέτυχε';
	$lang['strcreate'] = 'Δημιουργία';
	$lang['strcreated'] = 'Δημιουργήθηκε';
	$lang['strcomment'] = 'Σχόλιο';
	$lang['strlength'] = 'Μήκος';
	$lang['strdefault'] = 'Αρχική τιμή';
	$lang['stralter'] = 'Τροποποίηση';
	$lang['strok'] = 'Εντάξει';
	$lang['strcancel'] = 'Ακυρο';
	$lang['strac'] = 'Ενεργοποίηση Αυτόματης Συμπλήρωσης (AutoComplete)';
	$lang['strsave'] = 'Αποθήκευση';
	$lang['strreset'] = 'Καθαρισμός';
	$lang['strinsert'] = 'Εισαγωγή';
	$lang['strselect'] = 'Επιλογή';
	$lang['strdelete'] = 'Διαγραφή';
	$lang['strupdate'] = 'Ενημέρωση';
	$lang['strreferences'] = 'Σχέσεις';
	$lang['stryes'] = 'Ναι';
	$lang['strno'] = 'Οχι';
	$lang['strtrue'] = 'ΑΛΗΘΕΣ';
	$lang['strfalse'] = 'ΨΕΥΔΕΣ';
	$lang['stredit'] = 'Προσαρμογή';
	$lang['strcolumn'] = 'Στήλη';
	$lang['strcolumns'] = 'Στήλες';
	$lang['strrows'] = 'γραμμές';
	$lang['strrowsaff'] = 'γραμμές επηρεάστηκαν.';
	$lang['strobjects'] = 'αντικείμενα';
	$lang['strback'] = 'Πίσω';
	$lang['strqueryresults'] = 'Αποτελέσματα Ερωτήματος';
	$lang['strshow'] = 'Εμφάνιση';
	$lang['strempty'] = 'Αδειασμα';
	$lang['strlanguage'] = 'Γλώσσα';
	$lang['strencoding'] = 'Κωδικοποίηση';
	$lang['strvalue'] = 'Τιμή';
	$lang['strunique'] = 'Μοναδικό';
	$lang['strprimary'] = 'Πρωτεύον';
	$lang['strexport'] = 'Εξαγωγή';
	$lang['strimport'] = 'Εισαγωγή';
	$lang['strallowednulls'] = 'Επιτρεπόμενοι κενοί χαρακτήρες';
	$lang['strbackslashn'] = '\N';
	$lang['strnull'] = 'κενό';
	$lang['stremptystring'] = 'κενή συμβολοσειρά/κενό πεδίο';
	$lang['strsql'] = 'SQL';
	$lang['stradmin'] = 'Διαχείριση';
	$lang['strvacuum'] = 'Εκκένωση';
	$lang['stranalyze'] = 'Ανάλυση';
	$lang['strclusterindex'] = 'Ομαδοποίηση';
	$lang['strclustered'] = 'Ομαδοποιημένο';
	$lang['strreindex'] = 'Ανανέωση Ευρετηρίου';
	$lang['stradd'] = 'Προσθήκη';
	$lang['strevent'] = 'Ενέργεια';
	$lang['strwhere'] = 'Οπου';
	$lang['strinstead'] = 'Αντί να';
	$lang['strwhen'] = 'Πότε';
	$lang['strformat'] = 'Μορφή δεδομένων';
	$lang['strdata'] = 'Δεδομένα';
	$lang['strconfirm'] = 'Επιβεβαίωση';
	$lang['strexpression'] = 'Εκφραση';
	$lang['strellipsis'] = '...';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = 'Ανάπτυξη';
	$lang['strcollapse'] = 'Σύμπτυξη';
	$lang['strfind'] = 'Αναζήτηση';
	$lang['stroptions'] = 'Επιλογές';
	$lang['strrefresh'] = 'Ανανέωση';
	$lang['strdownload'] = 'Καταφόρτωση';
	$lang['strdownloadgzipped'] = 'Συμπίεση κατά gzip';
	$lang['strinfo'] = 'Πληροφορίες';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = 'Προχωρημένα';
	$lang['strvariables'] = 'Μεταβλητές';
	$lang['strprocess'] = 'Διεργασία';
	$lang['strprocesses'] = 'Διεργασίες';
	$lang['strsetting'] = 'Τιμή';
	$lang['streditsql'] = 'Επεξεργασία SQL';
	$lang['strruntime'] = 'Συνολικός χρόνος εκτέλεσης: %s ms';
	$lang['strpaginate'] = 'Σελιδοποίηση';
	$lang['struploadscript'] = 'ή ανεβάστε σενάριο (script) SQL:';
	$lang['strstarttime'] = 'Ωρα Εναρξης';
	$lang['strfile'] = 'Αρχείο';
	$lang['strfileimported'] = 'Αρχείο εισήχθη.';
	$lang['strtrycred'] = 'Χρήση αυτών των διαπιστευτηρίων για όλους τους διακομιστές';
	$lang['strexecute'] = 'Εκτέλεση';

	// Database Sizes
	$lang['strsize'] = 'Μέγεθος';
	$lang['strbytes'] = 'bytes';
	$lang['strkb'] = 'KB';
	$lang['strmb'] = 'MB';
	$lang['strgb'] = 'GB';
	$lang['strtb'] = 'TB';

	// Error handling
	$lang['strnoframes'] = 'Το phpPgAdmin λειτουργεί καλύτερα με προγράμματα πλοήγησης που υποστηρίζουν πλαίσια (frames). Εαν επιθυμείτε να συνεχίσετε ακολουθήστε την παρακάτω σύνδεση.';
	$lang['strnoframeslink'] = 'Χρήση χωρίς πλαίσια';
	$lang['strbadconfig'] = 'Το αρχείο config.inc.php είναι παλιό. Επαναδημιουργήστε το χρησιμοποιώντας το config.inc.php-dist.';
	$lang['strnotloaded'] = 'Η τρέχουσα εγκατάσταση της PHP δεν υποστηρίζει PostgreSQL. Εγκαταστήστε την πάλι με την επιλογή --with-pgsql (compilation option).';
	$lang['strpostgresqlversionnotsupported'] = 'Η τρέχουσα έκδοση της PostgreSQL δεν υποστηρίζεται από το phpPgAdmin. Παρακαλώ αναβαθμίστε στην έκδοση %s ή νεότερη.';
	$lang['strbadschema'] = 'Το σχήμα που δηλώθηκε δεν είναι έγκυρο.';
	$lang['strbadencoding'] = 'Αποτυχία ορισμού κωδικοποίησης στη βάση δεδομένων.';
	$lang['strsqlerror'] = 'Σφάλμα στην SQL:';
	$lang['strinstatement'] = 'Στη δήλωση:';
	$lang['strinvalidparam'] = 'Λάθος παράμετροι.';
	$lang['strnodata'] = 'Δε βρέθηκαν γραμμές.';
	$lang['strnoobjects'] = 'Δε βρέθηκαν αντικείμενα.';
	$lang['strrownotunique'] = 'Δε βρέθηκε μοναδικό κλειδί στη γραμμή.';
	$lang['strnouploads'] = 'Η αποστολή αρχείων είναι απενεργοποιημένη.';
	$lang['strimporterror'] = 'Σφάλμα κατά την εισαγωγή.';
	$lang['strimporterror-fileformat'] = 'Σφάλμα κατά την εισαγωγή: απέτυχε η αυτόματη αναγνώριση του τύπου του αρχείου.';
	$lang['strimporterrorline'] = 'Σφάλμα κατά την εισαγωγή της γραμμής %s.';
	$lang['strimporterrorline-badcolumnnum'] = 'Σφάλμα κατά την εισαγωγή της γραμμής %s: δεν περιέχει το σωστό αριθμό στηλών.';
	$lang['strimporterror-uploadedfile'] = 'Σφάλμα κατά την εισαγωγή: αποτυχία αποστολής στο διακομιστή.';
	$lang['strcannotdumponwindows'] = 'Η αποτύπωση (dumping) περίπλοκων πινάκων και σχημάτων (schemas) δεν υποστηρίζεται στα Windows.';

	// Tables
	$lang['strtable'] = 'Πίνακας';
	$lang['strtables'] = 'Πίνακες';
	$lang['strshowalltables'] = 'Εμφάνιση όλων των πινάκων';
	$lang['strnotables'] = 'Δεν βρέθηκαν πίνακες.';
	$lang['strnotable'] = 'Δε βρέθηκε πίνακας.';
	$lang['strcreatetable'] = 'Δημιουργία πίνακα';
	$lang['strtablename'] = 'Ονομα πίνακα';
	$lang['strtableneedsname'] = 'Πρέπει να εισάγετε το όνομα του πίνακα.';
	$lang['strtableneedsfield'] = 'Πρέπει να εισάγετε τουλάχιστον ένα πεδίο.';
	$lang['strtableneedscols'] = 'Πρέπει να εισάγετε έγκυρο αριθμό στηλών.';
	$lang['strtablecreated'] = 'Ο πίνακας δημιουργήθηκε.';
	$lang['strtablecreatedbad'] = 'Η δημιουργία του πίνακα απέτυχε.';
	$lang['strconfdroptable'] = 'Διαγραφή του πίνακα "%s"?';
	$lang['strtabledropped'] = 'Ο πίνακας διαγράφηκε.';
	$lang['strtabledroppedbad'] = 'Η διαγραφή του πίνακα απέτυχε.';
	$lang['strconfemptytable'] = 'Διαγραφή των περιεχομένων του πίνακα "%s"?';
	$lang['strtableemptied'] = 'Τα περιεχόμενα του πίνακα διαγράφηκαν.';
	$lang['strtableemptiedbad'] = 'Η διαγραφή των περιεχομένων του πίνακα απέτυχε.';
	$lang['strinsertrow'] = 'Εισαγωγή γραμμής';
	$lang['strrowinserted'] = 'Η γραμμή εισήχθη.';
	$lang['strrowinsertedbad'] = 'H εισαγωγή της γραμμής απέτυχε.';
	$lang['strrowduplicate'] = 'H εισαγωγή της γραμμής απέτυχε, διπλή εγγραφή.';
	$lang['streditrow'] = 'Επεξεργασία γραμμής';
	$lang['strrowupdated'] = 'Η γραμμή ενημερώθηκε.';
	$lang['strrowupdatedbad'] = 'Η ενημέρωση της γραμμής απέτυχε.';
	$lang['strdeleterow'] = 'Διαγραφή γραμμής';
	$lang['strconfdeleterow'] = 'Διαγραφή της γραμμής?';
	$lang['strrowdeleted'] = 'Η γραμμή διαγράφηκε.';
	$lang['strrowdeletedbad'] = 'Η διαγραφή της γραμμής απέτυχε.';
	$lang['strinsertandrepeat'] = 'Εισαγωγή και επανάληψη';
	$lang['strnumcols'] = 'Αριθμός στηλών';
	$lang['strcolneedsname'] = 'Πρέπει να ορίσετε το όνομα της στήλης';
	$lang['strselectallfields'] = 'Επιλογή όλων των πεδίων';
	$lang['strselectneedscol'] = 'Πρέπει να εμφανιστεί τουλάχιστον μία στήλη.';
	$lang['strselectunary'] = 'Οι μονοτελείς τελεστές (unary operators) δεν πρέπει να έχουν τιμές.';
	$lang['strcolumnaltered'] = 'Η στήλη τροποποιήθηκε.';
	$lang['strcolumnalteredbad'] = 'Η τροποποίηση της στήλης απέτυχε.';
	$lang['strconfdropcolumn'] = 'Διαγραφή στήλης "%s" από τον πίνακα "%s"?';
	$lang['strcolumndropped'] = 'Η στήλη διαγράφηκε.';
	$lang['strcolumndroppedbad'] = 'Η διαγραφή της στήλης απέτυχε.';
	$lang['straddcolumn'] = 'Εισαγωγή στήλης';
	$lang['strcolumnadded'] = 'Η στήλη εισήχθη.';
	$lang['strcolumnaddedbad'] = 'Η εισαγωγή της στήλης απέτυχε.';
	$lang['strcascade'] = 'ΔΙΑΤΑΞΗ';
	$lang['strtablealtered'] = 'Ο πίνακας τροποποιήθηκε.'; 
	$lang['strtablealteredbad'] = 'Η τροποποίηση του πίνακα απέτυχε.';
	$lang['strdataonly'] = 'Μόνο τα δεδομένα';
	$lang['strstructureonly'] = 'Μόνο τη δομή';
	$lang['strstructureanddata'] = 'Δομή και δεδομένα';
	$lang['strtabbed'] = 'Με στηλοθέτες';
	$lang['strauto'] = 'Αυτόματα';
	$lang['strconfvacuumtable'] = 'Να εκκενωθεί ο πίνακας "%s"?';
	$lang['strestimatedrowcount'] = 'Εκτιμώμενος αριθμός γραμμών';

	// Columns
	$lang['strcolprop'] = 'Ιδιότητες Στήλης';
		
	// Users
	$lang['struser'] = 'Χρήστη';
	$lang['strusers'] = 'Χρήστες';
	$lang['strusername'] = 'Ονομα χρήστη';
	$lang['strpassword'] = 'Κωδικός χρήστη';
	$lang['strsuper'] = 'Υπερχρήστης?';
	$lang['strcreatedb'] = 'Δημιουργία βάσης?';
	$lang['strexpires'] = 'Λήξη';
	$lang['strsessiondefaults'] = 'Εξ ορισμού παράμετροι συνεδρίας';
	$lang['strnousers'] = 'Δε βρέθηκαν χρήστες.';
	$lang['struserupdated'] = 'Ο λογαριασμός χρήστη ενημερώθηκε.';
	$lang['struserupdatedbad'] = 'Η ενημέρωση του χρήστη απέτυχε.';
	$lang['strshowallusers'] = 'Εμφάνιση όλων των χρηστών';
	$lang['strcreateuser'] = 'Δημιουργία χρήστη';
	$lang['struserneedsname'] = 'Πρέπει να εισάγετε όνομα χρήστη.';
	$lang['strusercreated'] = 'Ο χρήστης δημιουργήθηκε.';
	$lang['strusercreatedbad'] = 'Η δημιουργία του χρήστη απέτυχε.';
	$lang['strconfdropuser'] = 'Διαγραφή του χρήστη "%s"?';
	$lang['struserdropped'] = 'Ο χρήστης διαγράφηκε.';
	$lang['struserdroppedbad'] = 'Η διαγραφή του χρήστη απέτυχε.';
	$lang['straccount'] = 'Λογαριασμός';
	$lang['strchangepassword'] = 'Αλλαγή κωδικού';
	$lang['strpasswordchanged'] = 'Ο κωδικός αλλάχθηκε.';
	$lang['strpasswordchangedbad'] = 'Η αλλαγή του κωδικού απέτυχε.';
	$lang['strpasswordshort'] = 'Ο κωδικός έχει πολύ μικρό μήκος.';
	$lang['strpasswordconfirm'] = 'Σφάλμα στην επιβεβαίωση του κωδικού.';
	
	// Groups
	$lang['strgroup'] = 'Ομάδα';
	$lang['strgroups'] = 'Ομάδες';
	$lang['strnogroup'] = 'Η ομάδα δε βρέθηκε.';
	$lang['strnogroups'] = 'Δε βρέθηκαν ομάδες.';
	$lang['strcreategroup'] = 'Δημιουργία ομάδας';
	$lang['strshowallgroups'] = 'Εμφάνιση όλων των ομάδων';
	$lang['strgroupneedsname'] = 'Πρέπει να δώσετε όνομα στην ομάδα.';
	$lang['strgroupcreated'] = 'Η ομάδα δημιουργήθηκε.';
	$lang['strgroupcreatedbad'] = 'Η δημιουργία ομάδας απέτυχε.';	
	$lang['strconfdropgroup'] = 'Διαγραφή της ομάδας "%s"?';
	$lang['strgroupdropped'] = 'Η ομάδα διαγράφηκε.';
	$lang['strgroupdroppedbad'] = 'Η διαγραφή της ομάδας απέτυχε.';
	$lang['strmembers'] = 'Μέλη';
	$lang['strmemberof'] = 'Μέλος της ομάδας';
	$lang['stradminmembers'] = 'Μέλη της ομάδας διαχειριστών';
	$lang['straddmember'] = 'Προσθήκη μέλους';
	$lang['strmemberadded'] = 'Το μέλος προστέθηκε στην ομάδα.';
	$lang['strmemberaddedbad'] = 'Η προσθήκη του μέλους απέτυχε.';
	$lang['strdropmember'] = 'Διαγραφή μέλους';
	$lang['strconfdropmember'] = 'Διαγραφή του μέλους "%s" από την ομάδα "%s"?';
	$lang['strmemberdropped'] = 'Το μέλος διαγράφηκε.';
	$lang['strmemberdroppedbad'] = 'Η διαγραφή του μέλους απέτυχε.';
	
	// Roles
	$lang['strrole'] = 'Ρόλος';
	$lang['strroles'] = 'Ρόλοι';
	$lang['strshowallroles'] = 'Εμφάνιση όλων των ρόλων';
	$lang['strinheritsprivs'] = 'Κληρονομεί προνόμια?';
	$lang['strcreaterole'] = 'Δημιουργία ρόλου';
	$lang['strcancreaterole'] = 'Δημιουργία ρόλου?';
	$lang['strrolecreated'] = 'Ο ρόλος δημιουργήθηκε.';
	$lang['strrolecreatedbad'] = 'Η δημιουργία του ρόλου απέτυχε.';
	$lang['strcanlogin'] = 'Επιτρέπεται η σύνδεση?';
	$lang['strconnlimit'] = 'Οριο συνδέσεων';
	$lang['strdroprole'] = 'Διαγραφή ρόλου';
	$lang['strconfdroprole'] = 'Διαγραφή του ρόλου "%s"?';
	$lang['strroledropped'] = 'Ο ρόλος διαγράφηκε.';
	$lang['strroledroppedbad'] = 'Η διαγραφή του ρόλου απέτυχε.';
	$lang['strnoroles'] = 'Δε βρέθηκαν ρόλοι.';
	$lang['strnolimit'] = 'Κανένα όριο';
	$lang['strnever'] = 'Ποτέ';
	$lang['strroleneedsname'] = 'Πρέπει να δώσετε όνομα στο ρόλο.';

	// Privileges
	$lang['strprivilege'] = 'Προνόμιο';
	$lang['strprivileges'] = 'Προνόμια';
	$lang['strnoprivileges'] = 'Αυτό το αντικείμενο έχει τα εξ ορισμού προνόμια.';
	$lang['strgrant'] = 'Παροχή';
	$lang['strrevoke'] = 'Ανάκληση';
	$lang['strgranted'] = 'Τα προνόμια αλλάχθηκαν.';
	$lang['strgrantfailed'] = 'Αποτυχία αλλαγής προνομίων.';
	$lang['strgrantbad'] = 'Πρέπει να ορίσετε τουλάχιστον ένα χρήστη ή ομάδα και τουλάχιστον ένα προνόμιο.';
	$lang['strgrantor'] = 'Εκχωρητής';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Βάση';
	$lang['strdatabases'] = 'Βάσεις';
	$lang['strshowalldatabases'] = 'Εμφάνιση όλων των βάσεων';
	$lang['strnodatabases'] = 'Δε βρέθηκαν βάσεις.';
	$lang['strcreatedatabase'] = 'Δημιουργία βάσης';
	$lang['strdatabasename'] = 'Ονομα βάσης';
	$lang['strdatabaseneedsname'] = 'Πρέπει να δώσετε όνομα βάσης.';
	$lang['strdatabasecreated'] = 'Η βάση δημιουργήθηκε.';
	$lang['strdatabasecreatedbad'] = 'Η δημιουργία της βάσης απέτυχε.';
	$lang['strconfdropdatabase'] = 'Διαγραφή της βάσης "%s"?';
	$lang['strdatabasedropped'] = 'Η βάση διαγράφηκε.';
	$lang['strdatabasedroppedbad'] = 'Η δημιουργία της βάσης απέτυχε.';
	$lang['strentersql'] = 'Εισάγετε SQL προς εκτέλεση:';
	$lang['strsqlexecuted'] = 'H SQL εκτελέστηκε.';
	$lang['strvacuumgood'] = 'Η εκκένωση ολοκληρώθηκε.';
	$lang['strvacuumbad'] = 'Η εκκένωση απέτυχε.';
	$lang['stranalyzegood'] = 'Η ανάλυση ολοκληρώθηκε.';
	$lang['stranalyzebad'] = 'Η ανάλυση απέτυχε.';
	$lang['strreindexgood'] = 'Η επαναδεικτοδότηση ολοκληρώθηκε.';
	$lang['strreindexbad'] = 'Η επαναδεικτοδότηση απέτυχε.';
	$lang['strfull'] = 'Ολα';
	$lang['strfreeze'] = 'Πάγωμα';
	$lang['strforce'] = 'Υποχρεωτικά';
	$lang['strsignalsent'] = 'Το σήμα εστάλη.';
	$lang['strsignalsentbad'] = 'Η αποστολή του σήματος απέτυχε.';
	$lang['strallobjects'] = 'Ολα τα αντικείμενα';
	$lang['strdatabasealtered'] = 'Η βάση τροποποιήθηκε.'; 
	$lang['strdatabasealteredbad'] = 'Η τροποποίηση της βάσης απέτυχε.';

	// Views
	$lang['strview'] = 'Οψη';
	$lang['strviews'] = 'Οψεις';
	$lang['strshowallviews'] = 'Εμφάνιση όλων των όψεων';
	$lang['strnoview'] = 'Δε βρέθηκε όψη.';
	$lang['strnoviews'] = 'Δε βρέθηκαν όψεις.';
	$lang['strcreateview'] = 'Δημιουργία όψης';
	$lang['strviewname'] = 'Ονομα όψης';
	$lang['strviewneedsname'] = 'Πρέπει να δώσετε όνομα στην όψη.';
	$lang['strviewneedsdef'] = 'Πρέπει να δώσετε τον ορισμό της όψης.';
	$lang['strviewneedsfields'] = 'Πρέπει να δώσετε τις στήλες της όψης.';
	$lang['strviewcreated'] = 'Η όψη δημιουργήθηκε.';
	$lang['strviewcreatedbad'] = 'Η δημιουργία της όψης απέτυχε.';
	$lang['strconfdropview'] = 'Διαγραφή της όψης "%s"?';
	$lang['strviewdropped'] = 'Η όψη διαγράφηκε.';
	$lang['strviewdroppedbad'] = 'Η διαγραφή της όψης απέτυχε.';
	$lang['strviewupdated'] = 'Η όψη ενημερώθηκε.';
	$lang['strviewupdatedbad'] = 'Η ενημέρωση της όψης απέτυχε.';
	$lang['strviewlink'] = 'Σύζευξη κλειδιών';
	$lang['strviewconditions'] = 'Πρόσθετες συνθήκες';
	$lang['strcreateviewwiz'] = 'Δημιουργία όψης με βοηθό';

	// Sequences
	$lang['strsequence'] = 'Ακολουθία';
	$lang['strsequences'] = 'Ακολουθίες';
	$lang['strshowallsequences'] = 'Εμφάνιση όλων των ακολουθιών';
	$lang['strnosequence'] = 'Δε βρέθηκε ακολουθία.';
	$lang['strnosequences'] = 'Δε βρέθηκαν ακολουθίες.';
	$lang['strcreatesequence'] = 'Δημιουργία ακολουθίας';
	$lang['strlastvalue'] = 'Τελευταία τιμή';
	$lang['strincrementby'] = 'Προσαύξηση κατά';	
	$lang['strstartvalue'] = 'Τιμή εκκίνησης';
	$lang['strmaxvalue'] = 'Μέγιστη τιμή';
	$lang['strminvalue'] = 'Ελάχιστη τιμή';
	$lang['strcachevalue'] = 'Αριθμός εγγραφών στην κρυφή μνήμη (cache)';
	$lang['strlogcount'] = 'Καταγραφή';
	$lang['strcancycle'] = 'Να μηδενίζεται?';
	$lang['striscalled'] = 'Εχει κληθεί?';
	$lang['strsequenceneedsname'] = 'Πρέπει να δώσετε όνομα για την ακολουθία.';
	$lang['strsequencecreated'] = 'Η ακολουθία δημιουργήθηκε.';
	$lang['strsequencecreatedbad'] = 'Η δημιουργία της ακολουθίας απέτυχε.'; 
	$lang['strconfdropsequence'] = 'Να διαγραφεί η ακολουθία "%s"?';
	$lang['strsequencedropped'] = 'Η ακολουθία διαγράφηκε.';
	$lang['strsequencedroppedbad'] = 'Η διαγραφή της ακολουθίας απέτυχε.';
	$lang['strsequencereset'] = 'Η ακολουθία επανεκκινήθηκε.';
	$lang['strsequenceresetbad'] = 'Η επανεκκίνηση της ακολουθίας απέτυχε.'; 
 	$lang['strsequencealtered'] = 'Η ακολουθία τροποποιήθηκε.'; 
 	$lang['strsequencealteredbad'] = 'Η τροποποίηση της ακολουθίας απέτυχε.';
 	$lang['strsetval'] = 'Αλλαγή τιμής';
 	$lang['strsequencesetval'] = 'Η τιμή της ακολουθίας ορίσθηκε.';
 	$lang['strsequencesetvalbad'] = 'Απέτυχε ο ορισμός τιμής της ακολουθίας.';
 	$lang['strnextval'] = 'Προσαύξηση';
 	$lang['strsequencenextval'] = 'Η ακολουθία προσαυξήθηκε.';
 	$lang['strsequencenextvalbad'] = 'Η προσαύξηση της ακολουθίας απέτυχε.';

	// Indexes
	$lang['strindex'] = 'Ευρετήριο';
	$lang['strindexes'] = 'Ευρετήρια';
	$lang['strindexname'] = 'Ονομα ευρετηρίου';
	$lang['strshowallindexes'] = 'Εμφάνιση όλων των ευρετηρίων';
	$lang['strnoindex'] = 'Δε βρέθηκε ευρετήριο.';
	$lang['strnoindexes'] = 'Δε βρέθηκαν ευρετήρια.';
	$lang['strcreateindex'] = 'Δημιουργία ευρετηρίου';
	$lang['strtabname'] = 'Ονομα καρτέλας';
	$lang['strcolumnname'] = 'Ονομα στήλης';
	$lang['strindexneedsname'] = 'Πρέπει να δώσετε όνομα στο ευρετήριο.';
	$lang['strindexneedscols'] = 'Τα ευρετήρια απαιτούν έναν έγκυρο αριθμό στηλών.';
	$lang['strindexcreated'] = 'Το ευρετήριο δημιουργήθηκε.';
	$lang['strindexcreatedbad'] = 'Η δημιουργία του ευρετηρίου απέτυχε.';
	$lang['strconfdropindex'] = 'Να διαγραφεί το ευρετήριο "%s"?';
	$lang['strindexdropped'] = 'Το ευρετήριο διαγράφηκε.';
	$lang['strindexdroppedbad'] = 'Η διαγραφή του ευρετηρίου απέτυχε.';
	$lang['strkeyname'] = 'Ονομα κλειδιού';
	$lang['struniquekey'] = 'Μοναδικό κλειδί';
	$lang['strprimarykey'] = 'Πρωτεύον κλειδί';
 	$lang['strindextype'] = 'Τύπος ευρετηρίου';
	$lang['strtablecolumnlist'] = 'Στήλες πίνακα';
	$lang['strindexcolumnlist'] = 'Στήλες ευρετηρίου';
	$lang['strconfcluster'] = 'Να ομαδοποιηθούν τα "%s"?';
	$lang['strclusteredgood'] = 'Η ομαδοποίηση ολοκληρώθηκε.';
	$lang['strclusteredbad'] = 'Η ομαδοποίηση απέτυχε.';
	$lang['strcluster'] = 'Συστοιχία';

	// Rules
	$lang['strrules'] = 'Κανόνες';
	$lang['strrule'] = 'Κανόνας';
	$lang['strshowallrules'] = 'Εμφάνιση όλων των κανόνων';
	$lang['strnorule'] = 'Δε βρέθηκε κανόνας.';
	$lang['strnorules'] = 'Δε βρέθηκαν κανόνες.';
	$lang['strcreaterule'] = 'Δημιουργία κανόνα';
	$lang['strrulename'] = 'Ονομα κανόνα';
	$lang['strruleneedsname'] = 'Πρέπει να δώσετε όνομα στον κανόνα.';
	$lang['strrulecreated'] = 'Ο κανόνας δημιουργήθηκε.';
	$lang['strrulecreatedbad'] = 'Η δημιουργία του κανόνα απέτυχε.';
	$lang['strconfdroprule'] = 'Να διαγραφεί ο κανόνας "%s" στον "%s"?';
	$lang['strruledropped'] = 'Ο κανόνας διαγράφηκε.';
	$lang['strruledroppedbad'] = 'Η διαγραφή του κανόνα απέτυχε.';

	// Constraints
	$lang['strconstraint'] = 'Περιορισμός';
	$lang['strconstraints'] = 'Περιορισμοί';
	$lang['strshowallconstraints'] = 'Εμφάνιση όλων των περιορισμών';
	$lang['strnoconstraints'] = 'Δε βρέθηκαν περιορισμοί.';
	$lang['strcreateconstraint'] = 'Δημιουργία περιορισμού';
	$lang['strconstraintcreated'] = 'Ο περιορισμός δημιουργήθηκε.';
	$lang['strconstraintcreatedbad'] = 'Η δημιουργία του περιορισμού απέτυχε.';
	$lang['strconfdropconstraint'] = 'Να διαγραφεί ο περιορισμός "%s" στον "%s"?';
	$lang['strconstraintdropped'] = 'Ο περιορισμός διαγράφηκε.';
	$lang['strconstraintdroppedbad'] = 'Η διαγραφή του περιορισμού απέτυχε.';
	$lang['straddcheck'] = 'Προσθήκη ελέγχου';
	$lang['strcheckneedsdefinition'] = 'Πρέπει να οριστεί ο έλεγχος.';
	$lang['strcheckadded'] = 'Ο έλεγχος προστέθηκε.';
	$lang['strcheckaddedbad'] = 'Η προσθήκη ελέγχου απέτυχε.';
	$lang['straddpk'] = 'Προσθήκη πρωτεύοντος κλειδιού';
	$lang['strpkneedscols'] = 'Το πρωτεύον κλειδί χρειάζεται τουλάχιστον μία στήλη.';
	$lang['strpkadded'] = 'Το πρωτεύον κλειδί προστέθηκε.';
	$lang['strpkaddedbad'] = 'Αποτυχία προσθήκης πρωτεύοντος κλειδιού.';
	$lang['stradduniq'] = 'Προσθήκη μοναδικού κλειδιού';
	$lang['struniqneedscols'] = 'Το μοναδικό κλειδί χρειάζεται τουλάχιστον μία στήλη.';
	$lang['struniqadded'] = 'Το μοναδικό κλειδί προστέθηκε.';
	$lang['struniqaddedbad'] = 'Αποτυχία προσθήκης μοναδικού κλειδιού.';
	$lang['straddfk'] = 'Προσθήση ξένου κλειδιού';
	$lang['strfkneedscols'] = 'Το ξένο κλειδί χρειάζεται τουλάχιστον μία στήλη.';
	$lang['strfkneedstarget'] = 'Το ξένο κλειδί χρειάζεται ένα αποδέκτη πίνακα.';
	$lang['strfkadded'] = 'Το ξένο κλειδί προστέθηκε.';
	$lang['strfkaddedbad'] = 'Αποτυχία προσθήκης ξένου κλειδιού.';
	$lang['strfktarget'] = 'Αποδέκτης πίνακας';
	$lang['strfkcolumnlist'] = 'Στήλες στο κλειδί';
	$lang['strondelete'] = 'ΚΑΤΑ ΤΗ ΔΙΑΓΡΑΦΗ';
	$lang['stronupdate'] = 'ΚΑΤΑ ΤΗΝ ΕΝΗΜΕΡΩΣΗ';

	// Functions
	$lang['strfunction'] = 'Συνάρτηση';
	$lang['strfunctions'] = 'Συναρτήσεις';
	$lang['strshowallfunctions'] = 'Εμφάνιση όλων των συναρτήσεων';
	$lang['strnofunction'] = 'Δε βρέθηκε συνάρτηση.';
	$lang['strnofunctions'] = 'Δε βρέθηκαν συναρτήσεις.';
	$lang['strcreateplfunction'] = 'Δημιουργία συνάρτησης σε SQL/PL';
	$lang['strcreateinternalfunction'] = 'Δημιουργία εσωτερικής συνάρτησης';
	$lang['strcreatecfunction'] = 'Δημιουργία συνάρτησης σε C';
	$lang['strfunctionname'] = 'Ονομα συνάρτησης';
	$lang['strreturns'] = 'Επιστρέφει';
	$lang['strproglanguage'] = 'Γλώσσα προγραμματισμού';
	$lang['strfunctionneedsname'] = 'Πρέπει να δώσετε όνομα στη συνάρτηση.';
	$lang['strfunctionneedsdef'] = 'Πρέπει να δώσετε ορισμό στη συνάρτηση.';
	$lang['strfunctioncreated'] = 'Η συνάρτηση δημιουργήθηκε.';
	$lang['strfunctioncreatedbad'] = 'Η δημιουργία της συνάρτησης απέτυχε.';
	$lang['strconfdropfunction'] = 'Να διαγραφεί η συνάρτηση "%s"?';
	$lang['strfunctiondropped'] = 'Η συνάρτηση διαγράφηκε.';
	$lang['strfunctiondroppedbad'] = 'Η διαγραφή της συνάρτησης απέτυχε.';
	$lang['strfunctionupdated'] = 'Η συνάρτηση ενημερώθηκε.';
	$lang['strfunctionupdatedbad'] = 'Η ενημέρωση της συνάρτησης απέτυχε.';
	$lang['strobjectfile'] = 'Αρχείο αντικειμένου';
	$lang['strlinksymbol'] = 'Ονομα συνάρτησης στον πηγαίο κώδικα';
	$lang['strarguments'] = 'Ορίσματα';
	$lang['strargmode'] = 'Είδος';
	$lang['strargtype'] = 'Τύπος';
	$lang['strargadd'] = 'Επιπλέον όρισμα';
	$lang['strargremove'] = 'Διαγραφή ορίσματος';
	$lang['strargnoargs'] = 'Αυτή η συνάρτηση δεν έχει ορίσματα.';
	$lang['strargenableargs'] = 'Ενεργοποίηση ορισμάτων που τροφοδοτούν τη συνάρτηση.';
	$lang['strargnorowabove'] = 'Δεν υπάρχει γραμμή πάνω από αυτήν.';
	$lang['strargnorowbelow'] = 'Δεν υπάρχει γραμμή κάτω από αυτήν.';
	$lang['strargraise'] = 'Μετακίνηση πάνω.';
	$lang['strarglower'] = 'Μετακίνηση κάτω.';
	$lang['strargremoveconfirm'] = 'Να διαγραφεί το όρισμα; Η ενέργεια είναι ΜΗ ΑΝΑΣΤΡΕΨΙΜΗ.';


	// Triggers
	$lang['strtrigger'] = 'Εναυσμα';
	$lang['strtriggers'] = 'Εναύσματα';
	$lang['strshowalltriggers'] = 'Εμφάνιση όλων των εναυσμάτων';
	$lang['strnotrigger'] = 'Δε βρέθηκε έναυσμα.';
	$lang['strnotriggers'] = 'Δε βρέθηκαν εναύσματα.';
	$lang['strcreatetrigger'] = 'Δημιουργία εναύσματος';
	$lang['strtriggerneedsname'] = 'Πρέπει να δώσετε όνομα στο έναυσμα.';
	$lang['strtriggerneedsfunc'] = 'Το έναυσμα πρέπει να αντιστοιχεί σε μία συνάρτηση.';
	$lang['strtriggercreated'] = 'Το έναυσμα δημιουργήθηκε.';
	$lang['strtriggercreatedbad'] = 'Η δημιουργία του εναύσματος απέτυχε.';
	$lang['strconfdroptrigger'] = 'Να διαγραφεί το έναυσμα "%s" στον "%s"?';
	$lang['strconfenabletrigger'] = 'Να ενεργοποιηθεί το έναυσμα "%s" στον "%s"?';
	$lang['strconfdisabletrigger'] = 'Να απενεργοποιηθεί το έναυσμα "%s" στον "%s"?';
	$lang['strtriggerdropped'] = 'Το έναυσμα διαγράφηκε.';
	$lang['strtriggerdroppedbad'] = 'Η διαγραφή του εναύσματος απέτυχε.';
	$lang['strtriggerenabled'] = 'Το έναυσμα ενεργοποιήθηκε.';
	$lang['strtriggerenabledbad'] = 'Η ενεργοποίηση του εναύσματος απέτυχε.';
	$lang['strtriggerdisabled'] = 'Το έναυσμα απενεργοποιήθηκε.';
	$lang['strtriggerdisabledbad'] = 'Η απενεργοποίηση απέτυχε.';
	$lang['strtriggeraltered'] = 'Το έναυσμα τροποποιήθηκε.';
	$lang['strtriggeralteredbad'] = 'Η τροποποίηση του εναύσματος απέτυχε.';
	$lang['strforeach'] = 'Για κάθε';

	// Types
	$lang['strtype'] = 'Τύπος';
	$lang['strtypes'] = 'Τύποι';
	$lang['strshowalltypes'] = 'Εμφάνιση όλων των τύπων';
	$lang['strnotype'] = 'Δε βρέθηκε τύπος.';
	$lang['strnotypes'] = 'Δε βρέθηκαν τύποι.';
	$lang['strcreatetype'] = 'Δημιουργία τύπου';
	$lang['strcreatecomptype'] = 'Δημιουργία σύνθετου τύπου';
	$lang['strtypeneedsfield'] = 'Πρέπει να ορίσετε τουλάχιστον ένα πεδίο.';
	$lang['strtypeneedscols'] = 'Πρέπει να ορίσετε έναν έγκυρο αριθμό πεδίων.';	
	$lang['strinputfn'] = 'Συνάρτηση εισόδου';
	$lang['stroutputfn'] = 'Συνάρτηση εξόδου';
	$lang['strpassbyval'] = 'Να μεταφέρεται η μεταβλητή?';
	$lang['stralignment'] = 'Στοίχιση';
	$lang['strelement'] = 'Στοιχείο';
	$lang['strdelimiter'] = 'Διαχωριστής';
	$lang['strstorage'] = 'Αποθήκευση';
	$lang['strfield'] = 'Πεδίο';
	$lang['strnumfields'] = 'Αριθμός πεδίων';
	$lang['strtypeneedsname'] = 'Πρέπει να δώσετε όνομα στον τύπο.';
	$lang['strtypeneedslen'] = 'Πρέπει να ορίσετε το μήκος του τύπου.';
	$lang['strtypecreated'] = 'Ο τύπος δημιουργήθηκε.';
	$lang['strtypecreatedbad'] = 'Η δημιουργία του τύπου απέτυχε.';
	$lang['strconfdroptype'] = 'Να διαγραφεί ο τύπος "%s"?';
	$lang['strtypedropped'] = 'Ο τύπος διαγράφηκε.';
	$lang['strtypedroppedbad'] = 'Η διαγραφή του τύπου απέτυχε.';
	$lang['strflavor'] = 'Εντύπωση';
	$lang['strbasetype'] = 'Βάση';
	$lang['strcompositetype'] = 'Σύνθεση';
	$lang['strpseudotype'] = 'Ψεύδο';

	// Schemas
	$lang['strschema'] = 'Σχήμα';
	$lang['strschemas'] = 'Σχήματα';
	$lang['strshowallschemas'] = 'Εμφάνιση όλων των σχημάτων';
	$lang['strnoschema'] = 'Δε βρέθηκε σχήμα.';
	$lang['strnoschemas'] = 'Δε βρέθηκαν σχήματα.';
	$lang['strcreateschema'] = 'Δημιουργία σχήματος';
	$lang['strschemaname'] = 'Ονομα σχήματος';
	$lang['strschemaneedsname'] = 'Πρέπει να δώσετε όνομα στο σχήμα.';
	$lang['strschemacreated'] = 'Το σχήμα δημιουργήθηκε';
	$lang['strschemacreatedbad'] = 'Η δημιουργία του σχήματος απέτυχε.';
	$lang['strconfdropschema'] = 'Να διαγραφεί το σχήμα "%s"?';
	$lang['strschemadropped'] = 'Το σχήμα διαγράφηκε.';
	$lang['strschemadroppedbad'] = 'Η διαγραφή του σχήματος απέτυχε.';
	$lang['strschemaaltered'] = 'Το σχήμα τροποποιήθηκε.';
	$lang['strschemaalteredbad'] = 'Η τροποποίηση του σχήματος απέτυχε.';
	$lang['strsearchpath'] = 'Πορεία αναζήτησης σχήματος';

	// Reports

	// Domains
	$lang['strdomain'] = 'Τομέας';
	$lang['strdomains'] = 'Τομείς';
	$lang['strshowalldomains'] = 'Εμφάνιση όλων των τομέων';
	$lang['strnodomains'] = 'Δε βρέθηκαν τομείς.';
	$lang['strcreatedomain'] = 'Δημιουργία τομέα';
	$lang['strdomaindropped'] = 'Ο τομέας διαγράφηκε.';
	$lang['strdomaindroppedbad'] = 'Η διαγραφή του τομέα απέτυχε.';
	$lang['strconfdropdomain'] = 'Να διαγραφεί ο τομέας "%s"?';
	$lang['strdomainneedsname'] = 'Πρέπει να δώσετε όνομα στον τομέα.';
	$lang['strdomaincreated'] = 'Ο τομέας δημιουργήθηκε.';
	$lang['strdomaincreatedbad'] = 'Η δημιουργία του τομέα απέτυχε.';	
	$lang['strdomainaltered'] = 'Ο τομέας τροποποιήθηκε.';
	$lang['strdomainalteredbad'] = 'Η τροποποίηση του τομέα απέτυχε.';	

	// Operators
	$lang['stroperator'] = 'Τελεστής';
	$lang['stroperators'] = 'Τελεστές';
	$lang['strshowalloperators'] = 'Εμφάνιση όλων των τελεστών';
	$lang['strnooperator'] = 'Δε βρέθηκε τελεστής.';
	$lang['strnooperators'] = 'Δε βρέθηκαν τελεστές.';
	$lang['strcreateoperator'] = 'Δημιουργία τελεστή';
	$lang['strleftarg'] = 'Είδος αριστερής παραμέτρου';
	$lang['strrightarg'] = 'Είδος δεξιάς παραμέτρου';
	$lang['strcommutator'] = 'Αντιμετάθεση';
	$lang['strnegator'] = 'Αρνηση';
	$lang['strrestrict'] = 'Περιορισμός';
	$lang['strjoin'] = 'Σύζευξη';
	$lang['strhashes'] = 'Κατάτμηση';
	$lang['strmerges'] = 'Ενωση';
	$lang['strleftsort'] = 'Αριστερή ταξινόμηση';
	$lang['strrightsort'] = 'Δεξιά ταξινόμηση';
	$lang['strlessthan'] = 'Μικρότερο από';
	$lang['strgreaterthan'] = 'Μεγαλύτερο από';
	$lang['stroperatorneedsname'] = 'Πρέπει να δώσετε όνομα στον τελεστή.';
	$lang['stroperatorcreated'] = 'Ο τελεστής δημιουργήθηκε';
	$lang['stroperatorcreatedbad'] = 'Η δημιουργία του τελεστή απέτυχε.';
	$lang['strconfdropoperator'] = 'Να διαγραφεί ο τελεστής "%s"?';
	$lang['stroperatordropped'] = 'Ο τελεστής διαγράφηκε.';
	$lang['stroperatordroppedbad'] = 'Η διαγραφή του τελεστή απέτυχε.';

	// Casts
	$lang['strcasts'] = 'Μετατροπή τύπου';
	$lang['strnocasts'] = 'Δε βρέθηκαν μετατροπές τύπου.';
	$lang['strsourcetype'] = 'Τύπος εισόδου';
	$lang['strtargettype'] = 'Τύπος εξόδου';
	$lang['strimplicit'] = 'Απόλυτη';
	$lang['strinassignment'] = 'Σε ανάθεση';
	$lang['strbinarycompat'] = '(Δυαδική συμβατότητα)';
	
	// Conversions
	$lang['strconversions'] = 'Μετατροπές';
	$lang['strnoconversions'] = 'Δε βρέθηκαν μετατροπές.';
	$lang['strsourceencoding'] = 'Κωδικοποίηση εισόδου';
	$lang['strtargetencoding'] = 'Κωδικοποίηση εξόδου';
	
	// Languages
	$lang['strlanguages'] = 'Γλώσσες';
	$lang['strnolanguages'] = 'Δε βρέθηκαν γλώσσες.';
	$lang['strtrusted'] = 'Αξιόπιστη';
	
	// Info
	$lang['strnoinfo'] = 'Δε βρέθηκαν πληροφορίες.';
	$lang['strreferringtables'] = 'Σχετικοί πίνακες';
	$lang['strparenttables'] = 'Γονικοί πίνακες';
	$lang['strchildtables'] = 'Θυγατρικοί πίνακες';

	// Aggregates
	$lang['straggregate'] = 'Συγκεντρωτική συνάρτηση';
	$lang['straggregates'] = 'Συγκεντρωτικές συναρτήσεις'; 
	$lang['strnoaggregates'] = 'Δε βρέθηκαν συγκεντρωτικές συναρτήσεις'; 
	$lang['stralltypes'] = '(Ολοι οι τύποι)';
	$lang['strcreateaggregate'] = 'Δημιουργία συγκεντρωτικής συνάρτησης';
	$lang['straggrbasetype'] = 'Μορφή δεδομένων εισόδου';
	$lang['straggrsfunc'] = 'Συνάρτηση μεταβολής κατάστασης';
	$lang['straggrstype'] = 'Μορφή δεδομένων κατάστασης';
	$lang['straggrffunc'] = 'Τελική συνάρτηση';
	$lang['straggrinitcond'] = 'Αρχική συνθήκη';
	$lang['straggrsortop'] = 'Τελεστής ταξινόμησης';
	$lang['strconfdropaggregate'] = 'Να διαγραφεί η συγκεντρωτική συνάρτηση "%s"?';
	$lang['straggregatedropped'] = 'Η συγκεντρωτική συνάρτηση διαγράφηκε.';
	$lang['straggregatedroppedbad'] = 'Η διαγραφή της συγκεντρωτικής συνάρτησης απέτυχε.';
	$lang['straggraltered'] = 'Η συγκεντρωτική συνάρτηση τροποποιήθηκε.';
	$lang['straggralteredbad'] = 'Η τροποποίηση της συγκεντρωτικής συνάρτησης απέτυχε.';
	$lang['straggrneedsname'] = 'Πρέπει να δώσετε όνομα στη συγκεντρωτική συνάρτηση.';
	$lang['straggrneedsbasetype'] = 'Πρέπει να δώσετε τη μορφή δεδομένων εισόδου της συγκεντρωτικής συνάρτησης';
	$lang['straggrneedssfunc'] = 'Πρέπει να δώσετε το όνομα της συνάρτησης μεταβολής κατάστασης';
	$lang['straggrneedsstype'] = 'Πρέπει να δώσετε τη μορφή δεδομένων της τιμής κατάστασης';
	$lang['straggrcreated'] = 'Η συγκεντρωτική συνάρτηση δημιουργήθηκε.';
	$lang['straggrcreatedbad'] = 'Η δημιουργία της συγκεντρωτικής συνάρτησης απέτυχε.';
	$lang['straggrshowall'] = 'Εμφάνιση όλων των συγκεντρωτικών συναρτήσεων';

	// Operator Classes
	$lang['stropclasses'] = 'Κλάσεις τελεστών';
	$lang['strnoopclasses'] = 'Δε βρέθηκαν κλάσεις τελεστών.';
	$lang['straccessmethod'] = 'Μέθοδος πρόσβασης';

	// Stats and performance
	$lang['strrowperf'] = 'Επιδόσεις γραμμών'; 
	$lang['strioperf'] = 'Επιδόσεις Εισόδου/Εξόδου';
	$lang['stridxrowperf'] = 'Επιδόσεις γραμμών ευρετηρίου';
	$lang['stridxioperf'] = 'Επιδόσεις Εισόδου/Εξόδου ευρετηρίου';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Αλληλουχία';
	$lang['strscan'] = 'Σάρωση';
	$lang['strread'] = 'Ανάγνωση';
	$lang['strfetch'] = 'Απόδοση';
	$lang['strheap'] = 'Σωρός';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'Ευρετήριο TOAST';
	$lang['strcache'] = 'Κρυφή μνήμη';
	$lang['strdisk'] = 'Δίσκος';
	$lang['strrows2'] = 'Γραμμές';

	// Tablespaces
	$lang['strtablespace'] = 'Τοποθεσία πίνακα';
	$lang['strtablespaces'] = 'Τοποθεσίες πινάκων';
	$lang['strshowalltablespaces'] = 'Εμφάνιση όλων των τοποθεσιών'; 
	$lang['strnotablespaces'] = 'Δε βρέθηκαν τοποθεσίες πινάκων.';
	$lang['strcreatetablespace'] = 'Δημιουργία τοποθεσίας πίνακα';
	$lang['strlocation'] = 'Τοποθεσία';
	$lang['strtablespaceneedsname'] = 'Πρέπει να δώσετε όνομα στην τοποθεσία.';
	$lang['strtablespaceneedsloc'] = 'Πρέπει να δώσετε την ακριβή θέση του καταλόγου όπου θα δημιουργηθεί ο πίνακας.';
	$lang['strtablespacecreated'] = 'Η τοποθεσία δημιουργήθηκε.';
	$lang['strtablespacecreatedbad'] = 'Η δημιουργία της τοποθεσίας απέτυχε.';
	$lang['strconfdroptablespace'] = 'Να διαγραφεί η τοποθεσία "%s"?';
	$lang['strtablespacedropped'] = 'Η τοποθεσία διαγράφηκε.';
	$lang['strtablespacedroppedbad'] = 'Η διαγραφή της τοποθεσίας απέτυχε.';
	$lang['strtablespacealtered'] = 'Η τοποθεσία τροποποιήθηκε.';
	$lang['strtablespacealteredbad'] = 'Η τροποποίηση της τοποθεσίας απέτυχε.';

	// Miscellaneous
	$lang['strtopbar'] = '%s στο %s:%s -- Είστε συνδεδεμένος ως "%s"';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strhelp'] = 'Βοήθεια';
	$lang['strhelpicon'] = '?';
	$lang['strlogintitle'] = 'Σύνδεση με %s';
	$lang['strlogoutmsg'] = 'Αποσύνδεση από %s';
	$lang['strloading'] = 'Φόρτωση...';
	$lang['strerrorloading'] = 'Σφάλμα στη φόρτωση';
	$lang['strclicktoreload'] = 'Να ξαναφορτωθεί';

	// Autovacuum
	$lang['strautovacuum'] = 'Αυτόματη εκκένωση'; 
	$lang['strturnedon'] = 'Ανοιχτή'; 
	$lang['strturnedoff'] = 'Κλειστή';
	$lang['strenabled'] = 'Ενεργοποιημένη'; 
	$lang['strvacuumbasethreshold'] = 'Βάση κατωφλίου εκκένωσης'; 
	$lang['strvacuumscalefactor'] = 'Συντελεστής κλίμακας εκκένωσης';  
	$lang['stranalybasethreshold'] = 'Ανάλυση βάσης κατωφλίου';  
	$lang['stranalyzescalefactor'] = 'Ανάλυση συντελεστή κλίμακας'; 
	$lang['strvacuumcostdelay'] = 'Καθυστέρηση κόστους εκκένωσης'; 
	$lang['strvacuumcostlimit'] = 'Οριο κόστους εκκένωσης';  

    // Table-level Locks
	$lang['strlocks'] = 'Κλειδώματα';
	$lang['strtransaction'] = 'Ταυτότητα συναλλαγής';
	$lang['strprocessid'] = 'Ταυτότητα διεργασίας';
	$lang['strmode'] = 'Τρόπος κλειδώματος';
	$lang['strislockheld'] = 'Διατηρείται το κλείδωμα?';

	// Prepared transactions
	$lang['strpreparedxacts'] = 'Ετοιμες συναλλαγές';
	$lang['strxactid'] = 'Ταυτότητα';
	$lang['strgid'] = 'Γενική ταυτότητα';
?>
