<?php
/**
 * Swedish language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Christian Tiberg <christian@commsoft.nu>
 */

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'en',
            DB_ERROR                    => 'Okänt fel',
            DB_ERROR_ALREADY_EXISTS     => 'finns redan',
            DB_ERROR_CANNOT_CREATE      => 'kan inte skapa',
            DB_ERROR_CANNOT_DELETE      => 'kan inte ta bort',
            DB_ERROR_CANNOT_DROP        => 'kan inte släppa',
            DB_ERROR_CONSTRAINT         => 'begränsning kränkt',
            DB_ERROR_DIVZERO            => 'division med noll',
            DB_ERROR_INVALID            => 'ogiltig',
            DB_ERROR_INVALID_DATE       => 'ogiltigt datum eller tid',
            DB_ERROR_INVALID_NUMBER     => 'ogiltigt tal',
            DB_ERROR_MISMATCH           => 'felaktig matchning',
            DB_ERROR_NODBSELECTED       => 'ingen databas vald',
            DB_ERROR_NOSUCHFIELD        => 'inget sådant fält',
            DB_ERROR_NOSUCHTABLE        => 'ingen sådan tabell',
            DB_ERROR_NOT_CAPABLE        => 'DB backend klarar det inte',
            DB_ERROR_NOT_FOUND          => 'finns inte',
            DB_ERROR_NOT_LOCKED         => 'inte låst',
            DB_ERROR_SYNTAX             => 'syntaxfel',
            DB_ERROR_UNSUPPORTED        => 'stöds ej',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'värde räknat på rad',
            DB_ERROR_INVALID_DSN        => 'ogiltig DSN',
            DB_ERROR_CONNECT_FAILED     => 'anslutning misslyckades',
            0	                       => 'inget fel', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'otillräckligt med data angivet',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'utökning hittades ej',
            DB_ERROR_NOSUCHDB           => 'ingen sådan databas',
            DB_ERROR_ACCESS_VIOLATION   => 'otillräckliga rättigheter'
);
