<?php
/**
 * Indonesian language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Bambang Riswanto <bamz3r@gmail.com>
 */

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'id',
            DB_ERROR                    => 'kesalahan tidak diketahui',
            DB_ERROR_ALREADY_EXISTS     => 'sudah ada',
            DB_ERROR_CANNOT_CREATE      => 'tak dapat membuat',
            DB_ERROR_CANNOT_DELETE      => 'tak dapat menghapus',
            DB_ERROR_CANNOT_DROP        => 'tak dapat menghapus',
            DB_ERROR_CONSTRAINT         => 'pelanggaran kendala',
            DB_ERROR_DIVZERO            => 'pembagian dengan 0',
            DB_ERROR_INVALID            => 'tidak sah',
            DB_ERROR_INVALID_DATE       => 'tanggal atau waktu tidak valid',
            DB_ERROR_INVALID_NUMBER     => 'nomor tidak sah',
            DB_ERROR_MISMATCH           => 'tak cocok',
            DB_ERROR_NODBSELECTED       => 'tak ada database dipilih',
            DB_ERROR_NOSUCHFIELD        => 'kolom tak ditemukan',
            DB_ERROR_NOSUCHTABLE        => 'tabel tak ditemukan',
            DB_ERROR_NOT_CAPABLE        => 'kemampuan DB tak memadai',
            DB_ERROR_NOT_FOUND          => 'tidak ditemukan',
            DB_ERROR_NOT_LOCKED         => 'tidak terkunci',
            DB_ERROR_SYNTAX             => 'kesalahan sintak',
            DB_ERROR_UNSUPPORTED        => 'tak didukung',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'menghitung isi pada baris',
            DB_ERROR_INVALID_DSN        => 'DSN tidak sah',
            DB_ERROR_CONNECT_FAILED     => 'koneksi gagal',
            0	                       => 'tak ada kesalahan', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'data yang dimasukan tidak memadai',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'ekstensi tak ditemukan',
            DB_ERROR_NOSUCHDB           => 'database tak ditemukan',
            DB_ERROR_ACCESS_VIOLATION   => 'izin tidak memadai',
            DB_ERROR_DEADLOCK           => 'kebuntuan terdeteksi',
            DB_ERROR_STATEMENT_TIMEOUT  => 'perintah kehabisan waktu',
            DB_ERROR_SERIALIZATION_FAILURE => 'tak dapat melanjutkan akses'
);
