<?php
/**
 * Portuguese (Brazilian) language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Levi Fukumori <levi@fukumori.com.br>
 */

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'pt-br',
            DB_ERROR                    => 'erro desconhecido',
            DB_ERROR_ALREADY_EXISTS     => 'já existe',
            DB_ERROR_CANNOT_CREATE      => 'impossível criar',
            DB_ERROR_CANNOT_DELETE      => 'impossível excluír',
            DB_ERROR_CANNOT_DROP        => 'impossível remover',
            DB_ERROR_CONSTRAINT         => 'violação do confinamente',
            DB_ERROR_DIVZERO            => 'divisão por zero',
            DB_ERROR_INVALID            => 'inválido',
            DB_ERROR_INVALID_DATE       => 'data ou hora inválida',
            DB_ERROR_INVALID_NUMBER     => 'número inválido',
            DB_ERROR_MISMATCH           => 'erro',
            DB_ERROR_NODBSELECTED       => 'nenhum banco de dados selecionado',
            DB_ERROR_NOSUCHFIELD        => 'campo inválido',
            DB_ERROR_NOSUCHTABLE        => 'tabela inexistente',
            DB_ERROR_NOT_CAPABLE        => 'capacidade inválida para este BD',
            DB_ERROR_NOT_FOUND          => 'não encontrado',
            DB_ERROR_NOT_LOCKED         => 'não bloqueado',
            DB_ERROR_SYNTAX             => 'erro de sintaxe',
            DB_ERROR_UNSUPPORTED        =>
'não suportado',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'a quantidade de colunas não corresponde ao de valores',
            DB_ERROR_INVALID_DSN        => 'DSN inválido',
            DB_ERROR_CONNECT_FAILED     => 'falha na conexão',
            0				=> 'sem erro', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'dados insuficientes',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'extensão não encontrada',
            DB_ERROR_NOSUCHDB           => 'banco de dados não encontrado',
            DB_ERROR_ACCESS_VIOLATION   => 'permissão insuficiente'
);
