<?php
/**
* Portuguese language file.
*/

    // Basic strings
    $plugin_lang['strplugindescription'] = 'Report plugin';
    $plugin_lang['strnoreportsdb'] = 'Não criou uma base de dados de relatório. Leia o ficheiro INSTALL para mais informações.';

    // Reports
    $plugin_lang['strreport'] = 'Relatório';			
    $plugin_lang['strreports'] = 'Relatórios';			
    $plugin_lang['strshowallreports'] = 'Exibir todos os relatórios';		
    $plugin_lang['strnoreports'] = 'Relatório não encontrado.';		
    $plugin_lang['strcreatereport'] = 'Criar relatório';		
    $plugin_lang['strreportdropped'] = 'Relatório eliminado.';		
    $plugin_lang['strreportdroppedbad'] = 'Falha ao eliminar o relatório.';		
    $plugin_lang['strconfdropreport'] = 'Tem certeza que quer eliminar o relatório "%s"?';		
    $plugin_lang['strreportneedsname'] = 'Dê um nome ao seu relatório.';	
    $plugin_lang['strreportneedsdef'] = 'Adicione a instrução SQL ao seu relatório.';	
    $plugin_lang['strreportcreated'] = 'Relatório salvo.';					
    $plugin_lang['strreportcreatedbad'] = 'Falha ao salvar o relatório.';		
?>
