<?php
/**
 * Occitan language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 */

$ADODB_LANG_ARRAY = array (
	'LANG'                      => 'oc',
	DB_ERROR                    => 'error desconeguda',
	DB_ERROR_ALREADY_EXISTS     => 'existís ja',
	DB_ERROR_CANNOT_CREATE      => 'creacion impossibla',
	DB_ERROR_CANNOT_DELETE      => 'escafament impossible',
	DB_ERROR_CANNOT_DROP        => 'supression impossibla',
	DB_ERROR_CONSTRAINT         => 'violacion de constrenta',
	DB_ERROR_DIVZERO            => 'division per zèro',
	DB_ERROR_INVALID            => 'invalid',
	DB_ERROR_INVALID_DATE       => 'data o ora invalida',
	DB_ERROR_INVALID_NUMBER     => 'nombre invalid',
	DB_ERROR_MISMATCH           => 'error de concordància',
	DB_ERROR_NODBSELECTED       => 'pas de basa de donadas de seleccionada',
	DB_ERROR_NOSUCHFIELD        => 'nom de colomna invalid',
	DB_ERROR_NOSUCHTABLE        => 'taula o vista inexistenta',
	DB_ERROR_NOT_CAPABLE        => 'foncion opcionala pas installada',
	DB_ERROR_NOT_FOUND          => 'pas trobat',
	DB_ERROR_NOT_LOCKED         => 'pas verrolhat',
	DB_ERROR_SYNTAX             => 'error de sintaxi',
	DB_ERROR_UNSUPPORTED        => 'pas suportat',
	DB_ERROR_VALUE_COUNT_ON_ROW => 'valor inserida tròp granda per colomna',
	DB_ERROR_INVALID_DSN        => 'DSN invalid',
	DB_ERROR_CONNECT_FAILED     => 'fracàs a la connexion',
	0                           => "pas d'error", // DB_OK
	DB_ERROR_NEED_MORE_DATA     => 'donadas provesidas insufisentas',
	DB_ERROR_EXTENSION_NOT_FOUND=> 'extension pas trobada',
	DB_ERROR_NOSUCHDB           => 'basa de donadas desconeguda',
	DB_ERROR_ACCESS_VIOLATION   => 'dreits insufisents'
);
