<?php
	/**
	 * Polish language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Nie utworzyłeś bazy raportów. Instrukcję znajdziesz w pliku INSTALL.';

	// Reports
	$plugin_lang['strreport'] = 'Raport';
	$plugin_lang['strreports'] = 'Raporty';
	$plugin_lang['strshowallreports'] = 'Pokaż wszystkie raporty';
	$plugin_lang['strnoreports'] = 'Nie znaleziono raportów.';
	$plugin_lang['strcreatereport'] = 'Utwórz raport';
	$plugin_lang['strreportdropped'] = 'Raport został usunięty.';
	$plugin_lang['strreportdroppedbad'] = 'Próba usunięcia raportu się nie powiodła.';
	$plugin_lang['strconfdropreport'] = 'Czy na pewno chcesz usunąć raport "%s"?';
	$plugin_lang['strreportneedsname'] = 'Musisz nazwać raport.';
	$plugin_lang['strreportneedsdef'] = 'Musisz podać zapytanie SQL definiujące raport.';
	$plugin_lang['strreportcreated'] = 'Raport został utworzony.';
	$plugin_lang['strreportcreatedbad'] = 'Próba utworzenia raportu się nie powiodła.';
?>
