<?php
/**
 * Czech language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Kamil Jakubovic <jake@host.sk>
 */

$ADODB_LANG_ARRAY = array (
            'LANG'                      => 'cz',
            DB_ERROR                    => 'neznámá chyba',
            DB_ERROR_ALREADY_EXISTS     => 'ji? existuje',
            DB_ERROR_CANNOT_CREATE      => 'nelze vytvo?it',
            DB_ERROR_CANNOT_DELETE      => 'nelze smazat',
            DB_ERROR_CANNOT_DROP        => 'nelze odstranit',
            DB_ERROR_CONSTRAINT         => 'poru?ení omezující podmínky',
            DB_ERROR_DIVZERO            => 'd?lení nulou',
            DB_ERROR_INVALID            => 'neplatné',
            DB_ERROR_INVALID_DATE       => 'neplatné datum nebo ?as',
            DB_ERROR_INVALID_NUMBER     => 'neplatné ?íslo',
            DB_ERROR_MISMATCH           => 'nesouhlasí',
            DB_ERROR_NODBSELECTED       => '?ádná databáze není vybrána',
            DB_ERROR_NOSUCHFIELD        => 'pole nenalezeno',
            DB_ERROR_NOSUCHTABLE        => 'tabulka nenalezena',
            DB_ERROR_NOT_CAPABLE        => 'nepodporováno',
            DB_ERROR_NOT_FOUND          => 'nenalezeno',
            DB_ERROR_NOT_LOCKED         => 'nezam?eno',
            DB_ERROR_SYNTAX             => 'syntaktická chyba',
            DB_ERROR_UNSUPPORTED        => 'nepodporováno',
            DB_ERROR_VALUE_COUNT_ON_ROW => '',
            DB_ERROR_INVALID_DSN        => 'neplatné DSN',
            DB_ERROR_CONNECT_FAILED     => 'p?ipojení selhalo',
            0	                        => 'bez chyb', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'málo zdrojových dat',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'roz?í?ení nenalezeno',
            DB_ERROR_NOSUCHDB           => 'databáze neexistuje',
            DB_ERROR_ACCESS_VIOLATION   => 'nedostate?ná práva'
);
