<?php
/**
 * Hungarian language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Halászvári Gábor <g.halaszvari@portmax.hu>
 */

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'hu',
            DB_ERROR                    => 'ismeretlen hiba',
            DB_ERROR_ALREADY_EXISTS     => 'már létezik',
            DB_ERROR_CANNOT_CREATE      => 'nem sikerült létrehozni',
            DB_ERROR_CANNOT_DELETE      => 'nem sikerült törölni',
            DB_ERROR_CANNOT_DROP        => 'nem sikerült eldobni',
            DB_ERROR_CONSTRAINT         => 'szabályok megszegése',
            DB_ERROR_DIVZERO            => 'osztás nullával',
            DB_ERROR_INVALID            => 'érvénytelen',
            DB_ERROR_INVALID_DATE       => 'érvénytelen dátum vagy idő',
            DB_ERROR_INVALID_NUMBER     => 'érvénytelen szám',
            DB_ERROR_MISMATCH           => 'nem megfelelő',
            DB_ERROR_NODBSELECTED       => 'nincs kiválasztott adatbázis',
            DB_ERROR_NOSUCHFIELD        => 'nincs ilyen mező',
            DB_ERROR_NOSUCHTABLE        => 'nincs ilyen tábla',
            DB_ERROR_NOT_CAPABLE        => 'DB backend nem támogatja',
            DB_ERROR_NOT_FOUND          => 'nem található',
            DB_ERROR_NOT_LOCKED         => 'nincs lezárva',
            DB_ERROR_SYNTAX             => 'szintaktikai hiba',
            DB_ERROR_UNSUPPORTED        => 'nem támogatott',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'soron végzett érték számlálás',
            DB_ERROR_INVALID_DSN        => 'hibás DSN',
            DB_ERROR_CONNECT_FAILED     => 'sikertelen csatlakozás',
            0	                       => 'nincs hiba', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'túl kevés az adat',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'bővítmény nem található',
            DB_ERROR_NOSUCHDB           => 'nincs ilyen adatbázis',
            DB_ERROR_ACCESS_VIOLATION   => 'nincs jogosultság'
);
