<?php

/**
* Portuguese language file for phpPgAdmin.
* @maintainer Francisco Alves Cabrita (include@npf.pt.freebsd.org)
*
*/

// Language and character set
$lang['applang'] = 'Português-Português';
$lang['applocale'] = 'pt-PT';
$lang['applangdir'] = 'ltr';
  
// Basic strings
$lang['strintro'] = 'Bem-vindo ao phpPgAdmin.';	
$lang['strppahome'] = 'Página inicial phpPgAdmin ';
$lang['strpgsqlhome'] = 'Página inicial PostgreSQL ';
$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
$lang['strreportbug'] = 'Relatório de Bug';
$lang['strviewfaq'] = 'Visualizar FAQ';
$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
$lang['strlogin'] = 'Autenticação';					
$lang['strloginfailed'] = 'Falha na autenticação';		
$lang['strserver'] = 'Servidor';					
$lang['strlogout'] = 'Sair';					
$lang['strowner'] = 'Propietário';					
$lang['straction'] = 'Acção';					
$lang['stractions'] = 'Acções';				
$lang['strname'] = 'Nome';						
$lang['strdefinition'] = 'Definição';		
$lang['stroperators'] = 'Operadores';			
$lang['straggregates'] = 'Agregados';			
$lang['strproperties'] = 'Propriedades';			
$lang['strbrowse'] = 'Navegar';					
$lang['strdrop'] = 'Eliminar';						
$lang['strdropped'] = 'Eliminado';				
$lang['strnull'] = 'Nulo';						
$lang['strnotnull'] = 'Não Nulo';				
$lang['strprev'] = 'Anterior';						
$lang['strnext'] = 'Próximo';							
$lang['strfailed'] = 'Falha';					
$lang['strcreate'] = 'Criar';					
$lang['strcreated'] = 'Criado';				
$lang['strcomment'] = 'Comentário';				
$lang['strlength'] = 'Extensão';					
$lang['strdefault'] = 'Padrão';
$lang['stralter'] = 'Alterar';
$lang['strok'] = 'OK';
$lang['strcancel'] = 'Cancelar';					
$lang['strsave'] = 'Gravar';						
$lang['strreset'] = 'Reiniciar';					
$lang['strinsert'] = 'Inserir';					
$lang['strselect'] = 'Seleccionar';					
$lang['strdelete'] = 'Eliminar';					
$lang['strupdate'] = 'Atualizar';				
$lang['strreferences'] = 'Referências';			
$lang['stryes'] = 'Sim';						
$lang['strno'] = 'Não';							
$lang['stredit'] = 'Editar';					
$lang['strcolumns'] = 'Colunas';				
$lang['strrows'] = 'Linha(s)';					
$lang['strrowsaff'] = 'Linha(s) afectadas.';		
$lang['strexample'] = 'eg.';					
$lang['strback'] = 'Voltar';						
$lang['strqueryresults'] = 'Resultados da pesquisa';		
$lang['strshow'] = 'Exibir';						
$lang['strempty'] = 'Vazio';					
$lang['strlanguage'] = 'Linguagem';				
$lang['strencoding'] = 'Codificação';				
$lang['strvalue'] = 'Valor';					
$lang['strunique'] = 'Único';					
$lang['strprimary'] = 'Primário';				
$lang['strexport'] = 'Exportar';				
$lang['strsql'] = 'SQL';						
$lang['strgo'] = 'Ir';							
$lang['strimport'] = 'Importar';
$lang['stradmin'] = 'Administrador';					
$lang['strvacuum'] = 'Vácuo';					
$lang['stranalyze'] = 'Analiza';				
$lang['strclusterindex'] = 'Cluster';				
$lang['strreindex'] = 'Reordenar';				
$lang['strrun'] = 'Executar';						
$lang['stradd'] = 'Adicionar';						
$lang['strevent'] = 'Evento';					
$lang['strwhere'] = 'Onde';					
$lang['strinstead'] = 'Fazer ao invés';				
$lang['strwhen'] = 'Quando';						
$lang['strformat'] = 'Formato';					
$lang['strstart'] = 'Iniciar';
$lang['strstop'] = 'Parar';
$lang['strgotoppage'] = 'Topo da página';

// Error handling
$lang['strdata'] = 'Data';
$lang['strconfirm'] = 'Confirmar';
$lang['strexpression'] = 'Expressão';
        $lang['strellipsis'] = '...';
$lang['strexpand'] = 'Expandir';
$lang['strcollapse'] = 'Diminuir';
$lang['strbadconfig'] = 'O config.inc.php está desatualizado. Você deve criá-lo novamente a partir do novo config.inc.php-dist.';
$lang['strnotloaded'] = 'A sua instalação do PHP não suporta chamadas a este tipo de base de dados.';
$lang['strbadschema'] = 'Esquema inválido.';
$lang['strbadencoding'] = 'Falha ao definir codificação do cliente na base de dados.';
$lang['strsqlerror'] = 'Erro de SQL:';
$lang['strinstatement'] = 'Indicação de entrada :';
$lang['strinvalidparam'] = 'Parâmetros de script inválidos.';
$lang['strnodata'] = 'Não foram encontradas linhas.';
$lang['strconnectionfail'] = 'A conexão falhou.';

// Tables
$lang['strtable'] = 'Tabela';
$lang['strtables'] = 'Tabelas';
$lang['strshowalltables'] = 'Exibir todas as tabelas';
$lang['strnotables'] = 'Tabelas não encontradas.';
$lang['strnotable'] = 'Tabela não encontradas.';
$lang['strcreatetable'] = 'Criar tabela';
$lang['strtablename'] = 'Nome da tabela ';
$lang['strtableneedsname'] = 'A tabela necessita de um nome.';
$lang['strtableneedsfield'] = 'Especifique pelo menos um campo.';
$lang['strtableneedscols'] = 'As tabelas requerem um número válido de colunas.';
$lang['strtablecreated'] = 'Tabela criada.';
$lang['strtablecreatedbad'] = 'Falha na criação de tabela.';
$lang['strconfdroptable'] = 'Tem certeza que quer eliminar a tabela "%s"?';
$lang['strtabledropped'] = 'Tabela eliminada.';
$lang['strtabledroppedbad'] = 'Falha ao eliminar a tabela.';
$lang['strconfemptytable'] = 'Tem certeza que quer esvaziar a tabela "%s"?';
$lang['strtableemptied'] = 'Tabela vazia.';
$lang['strtableemptiedbad'] = 'Falha ao esvaziar a tabela.';
$lang['strinsertrow'] = 'Inserir linha';
$lang['strrowinserted'] = 'Linha inserida.';
$lang['strrowinsertedbad'] = 'Falha ao inserir linha.';
$lang['streditrow'] = 'Editar linha';
$lang['strrowupdated'] = 'Linha actualizada.';
$lang['strrowupdatedbad'] = 'Falha na actualização da linha.';
$lang['strdeleterow'] = 'Eliminar linha';
$lang['strconfdeleterow'] = 'Tem certeza que quer eliminar esta linha?';
$lang['strrowdeleted'] = 'Linha eliminada.';
$lang['strrowdeletedbad'] = 'Falha ao eliminar a linha .';
$lang['strfield'] = 'Campo';
$lang['strnumfields'] = 'Número de campos';
$lang['strselectneedscol'] = 'Deve exibir pelo menos uma coluna';
$lang['straltercolumn'] = 'Alterar coluna';
$lang['strcolumnaltered'] = 'Coluna altereda.';
$lang['strcolumnalteredbad'] = 'Falha na alteração de coluna.';
$lang['strconfdropcolumn'] = 'Tem certeza que quer eliminar a coluna "%s" da tabela "%s"?';
$lang['strcolumndropped'] = 'Coluna eliminada.';
$lang['strcolumndroppedbad'] = 'Eliminação da coluna falhou.';
$lang['straddcolumn'] = 'Adicionar coluna';
$lang['strcolumnadded'] = 'Coluna adicionada.';
$lang['strcolumnaddedbad'] = 'Adição de coluna falhou.';
$lang['strdataonly'] = 'Dados apenas';

// Users
$lang['strcascade'] = 'CASCATA';
$lang['struser'] = 'Utilizador';
$lang['strusers'] = 'Utilizadores';
$lang['strusername'] = 'Nome do utilizador';
$lang['strpassword'] = 'Palavra-chave';
$lang['strsuper'] = 'Super-Utilizador?';
$lang['strcreatedb'] = 'Criar Base de Dados?';
$lang['strexpires'] = 'Expira';
$lang['strnousers'] = 'Utilizadores não encontrados.';
$lang['struserupdated'] = 'Utilizador alterado.';
$lang['struserupdatedbad'] = 'Alteração do utilizador falhou.';
$lang['strshowallusers'] = 'Mostra todos os utilizadores';
$lang['strcreateuser'] = 'Criar Utilizador';
$lang['strusercreated'] = 'Utilizador criado.';
$lang['strusercreatedbad'] = 'Falhou ao criar utilizador.';
$lang['strconfdropuser'] = 'Tem certeza que quer eliminar o utilizador "%s"?';
$lang['struserdropped'] = 'Utilizador eliminado.';
$lang['struserdroppedbad'] = 'Falha ao eliminar utilizador.';
		
// Groups
$lang['straccount'] = 'Conta';
$lang['strchangepassword'] = 'Alterar palavra-chave';
$lang['strpasswordchanged'] = 'Palavra-chave alterada.';
$lang['strpasswordchangedbad'] = 'Falha ao alterar palavra-passe.';
$lang['strpasswordshort'] = 'Palavra-chave muito curta.';
$lang['strpasswordconfirm'] = 'Palavra-chave não coincide com a confirmação.';
$lang['strgroup'] = 'Grupo';
$lang['strgroups'] = 'Grupos';
$lang['strnogroups'] = 'Grupos não encotrados.';
$lang['strshowallgroups'] = 'Exibir todos os grupos';
$lang['strgroupneedsname'] = 'Insira um nome para o seu grupo.';
$lang['strgroupcreated'] = 'Grupo criado.';
$lang['strgroupcreatedbad'] = 'Falha na criação de grupo.';	
$lang['strconfdropgroup'] = 'Tem certeza que quer eliminar o grupo "%s"?';
$lang['strgroupdropped'] = 'Grupo eliminado.';
$lang['strgroupdroppedbad'] = 'Falha ao eliminar grupo.';
$lang['strmembers'] = 'Membros';

// Privilges
$lang['strprivilege'] = 'Privilégio';
$lang['strprivileges'] = 'Privilégios';
$lang['strnoprivileges'] = 'Este objeto tem privilégios padrões de proprietário.';
$lang['strgrant'] = 'Concede';
$lang['strrevoke'] = 'Revoga';
$lang['strgranted'] = 'Privilágios concedidos.';
$lang['strgrantfailed'] = 'Falha ao conceder privilégios.';
$lang['strgrantbad'] = 'Deverá especificar um utilizador ou grupo e pelo menos um previlégio.';

// Databases
$lang['strdatabase'] = 'Base de dados';
$lang['strdatabases'] = 'Base de dados';
$lang['strshowalldatabases'] = 'Exibir todos os base de dados';
$lang['strnodatabase'] = 'Base de dados não encontrada.';
$lang['strnodatabases'] = 'Bases de dados não encontradas.';
$lang['strcreatedatabase'] = 'Criar base de dados';
$lang['strdatabasename'] = 'Nome da base de dados';
$lang['strdatabaseneedsname'] = 'Insira um nome para a sua base de dados.';
$lang['strdatabasecreated'] = 'Base de dados criada.';
$lang['strdatabasecreatedbad'] = 'Falhou na criação da Base de dados.';	
$lang['strconfdropdatabase'] = 'Tem certeza que quer eliminar a base de dados "%s"?';
$lang['strdatabasedropped'] = 'Base de dados eliminada.';
$lang['strdatabasedroppedbad'] = 'Falha ao eliminar a base de dados.';
$lang['strentersql'] = 'Digite abaixo a instrução SQL a ser executado:';
$lang['strsqlexecuted'] = 'SQL executado.';
$lang['strvacuumgood'] = 'Vácuo completo.';
$lang['strvacuumbad'] = 'Falha ao executar vácuo.';
$lang['stranalyzegood'] = 'Análize completa.';
$lang['stranalyzebad'] = 'Falha ao executar análize.';

// Views
$lang['strview'] = 'Visualização';
$lang['strviews'] = 'Visualizações';
$lang['strshowallviews'] = 'Exibir todas as visualizações';
$lang['strnoview'] = 'Visualização não encontrada.';
$lang['strnoviews'] = 'Visualizações não encontradas.';
$lang['strcreateview'] = 'Criar visualização';
$lang['strviewname'] = 'Nome da visualização';
$lang['strviewneedsname'] = 'Você deve dar um nome a sua visualização.';
$lang['strviewneedsdef'] = 'Crie uma definição para sua visualização.';
$lang['strviewcreated'] = 'Visualização criada.';
$lang['strviewcreatedbad'] = 'Falha na criação de visualização.';
$lang['strconfdropview'] = 'Tem certeza que quer eliminar a visualização "%s"?';
$lang['strviewdropped'] = 'Visualização eliminada.';
$lang['strviewdroppedbad'] = 'Falha ao eliminar a visualização.';
$lang['strviewupdated'] = 'Visualização alterada.';
$lang['strviewupdatedbad'] = 'Falha ao alterar visualização.';

// Sequences
$lang['strsequence'] = 'Sequência';
$lang['strsequences'] = 'Sequências';
$lang['strshowallsequences'] = 'Listar todas as sequências';
$lang['strnosequence'] = 'Sequência não encontrada.';
$lang['strnosequences'] = 'Sequências não encontradas.';
$lang['strcreatesequence'] = 'Criar sequência';
$lang['strlastvalue'] = 'Último valor';
$lang['strincrementby'] = 'Incrementar por';	
$lang['strstartvalue'] = 'Valor inicial';
$lang['strmaxvalue'] = 'Valor máximo';
$lang['strminvalue'] = 'Valor mínimo';
$lang['strcachevalue'] = 'Valor de cache';
$lang['strlogcount'] = 'Contador do log';
	$lang['striscycled'] = 'Foi dado um ciclo ?';
$lang['strsequenceneedsname'] = 'Dê um nome a sua sequência.';
$lang['strsequencecreated'] = 'Sequência criada.';
$lang['strsequencecreatedbad'] = 'Falha na criação da sequência.'; 
$lang['strconfdropsequence'] = 'Tem certeza que quer eliminar a sequência "%s"?';
$lang['strsequencedropped'] = 'Sequência eliminada.';
$lang['strsequencedroppedbad'] = 'Falha ao eliminar a sequência.';

// Indexes
$lang['strindexes'] = 'Índices';
$lang['strindexname'] = 'Nome do índice';
$lang['strshowallindexes'] = 'Exibir todos os índices';
$lang['strnoindex'] = 'Índice não encontrado.';
$lang['strnoindexes'] = 'Índices não encontrados.';
$lang['strcreateindex'] = 'Criar índice';
$lang['strindexname'] = 'Nome do índice';
$lang['strtabname'] = 'Nome da tabela';
$lang['strcolumnname'] = 'Nome da coluna';
$lang['strindexneedsname'] = 'Dê um nome ao seu índice';
$lang['strindexneedscols'] = 'Índices requerem um número válido de colunas.';
$lang['strindexcreated'] = 'Índice criado';
$lang['strindexcreatedbad'] = 'Falha na criação do índice.';
$lang['strconfdropindex'] = 'Tem a certeza que quer eliminar o índice "%s"?';
$lang['strindexdropped'] = 'Indice eliminado.';
$lang['strindexdroppedbad'] = 'Falha ao eliminar o índice.';
$lang['strkeyname'] = 'Nome da chave';
$lang['struniquekey'] = 'Chave única';
$lang['strprimarykey'] = 'Chave primária';
$lang['strindextype'] = 'Tipo de índice';
$lang['strindexname'] = 'Nome do índice';
$lang['strtablecolumnlist'] = 'Colunas na tabela';
$lang['strindexcolumnlist'] = 'Colunas no índice';

// Rules
$lang['strrules'] = 'Regras';
$lang['strrule'] = 'Regra';
$lang['strshowallrules'] = 'Exibir todas as regras';
$lang['strnorule'] = 'Regra não encontrada.';
$lang['strnorules'] = 'Regras não encontradas.';
$lang['strcreaterule'] = 'Criar regra';
$lang['strrulename'] = 'Nome da regra';
$lang['strruleneedsname'] = 'Dê um nome para sua regra.';
$lang['strrulecreated'] = 'Regra criada.';
$lang['strrulecreatedbad'] = 'Falha na criação de regra.';
$lang['strconfdroprule'] = 'Tem certeza que quer eliminar a regra "%s" on "%s"?';
$lang['strruledropped'] = 'Regra eliminada.';
$lang['strruledroppedbad'] = 'Falha ao eliminar a regra.';

// Constraints
$lang['strconstraints'] = 'Restrição';
$lang['strshowallconstraints'] = 'Exibir todos as restrições';
$lang['strnoconstraints'] = 'Restrições não encontradas.';
$lang['strcreateconstraint'] = 'Criar restrição';
$lang['strconstraintcreated'] = 'Restrição criada.';
$lang['strconstraintcreatedbad'] = 'Falha na criação de restrição.';
$lang['strconfdropconstraint'] = 'Tem certeza que quer eliminar a restrição "%s" on "%s"?';
$lang['strconstraintdropped'] = 'Restrição eliminada.';
$lang['strconstraintdroppedbad'] = 'Falha ao eliminar de restrição.';
$lang['straddcheck'] = 'Adicona verificação';
$lang['strcheckneedsdefinition'] = 'Verificação de regras necessita de uma definição.';
$lang['strcheckadded'] = 'Verificação de restrição adicionada.';
$lang['strcheckaddedbad'] = 'Falha ao adicionar verificação de restrição.';
$lang['straddpk'] = 'Adicionar chave primária';
$lang['strpkneedscols'] = 'Chave primária requer pelo menos uma coluna.';
$lang['strpkadded'] = 'Chave primária adicionada.';
$lang['strpkaddedbad'] = 'Falha ao adicinoar chave primária.';
$lang['stradduniq'] = 'Adiciona chave única';
$lang['struniqneedscols'] = 'Chave única requer ao menos uma coluna.';					
$lang['struniqadded'] = 'Chave única adicionada.';
$lang['struniqaddedbad'] = 'Falha ao adicionar chave única.';
$lang['straddfk'] = 'Adicionar chave estrangeira';
$lang['strfkneedscols'] = 'Chave estrangeira requer ao menos uma coluna.';
$lang['strfkneedstarget'] = 'Chave estrangeira requer uma tabela de referência.';
$lang['strfkadded'] = 'Chave estrangeira adicionada.';
$lang['strfkaddedbad'] = 'Falha ao adicionar chave estrangeira.';
$lang['strfktarget'] = 'Tabela alvo';
$lang['strfkcolumnlist'] = 'Colunas em chaves';									
$lang['strondelete'] = 'ELIMINAR ACTIVO';
$lang['stronupdate'] = 'ALTERAR ACTIVO';

// Functions
$lang['strfunction'] = 'Função';
$lang['strfunctions'] = 'Funções';
$lang['strshowallfunctions'] = 'Exibir todas as funções';
$lang['strnofunction'] = 'Função não encontrada.';
$lang['strnofunctions'] = 'Funções não encontradas.';
$lang['strfunctionname'] = 'Nome da função';
$lang['strreturns'] = 'Retorno';
$lang['strarguments'] = 'Argumentos';
$lang['strproglanguage'] = 'Linguagem';				
$lang['strfunctionneedsname'] = 'Dê um nome à sua função.';
$lang['strfunctionneedsdef'] = 'A função precisa de uma definição.';
$lang['strfunctioncreated'] = 'Função criada.';
$lang['strfunctioncreatedbad'] = 'Falha na criação de função.';
$lang['strconfdropfunction'] = 'Tem certeza que quer eliminar a função "%s"?';
$lang['strfunctiondropped'] = 'Função eliminada.';
$lang['strfunctiondroppedbad'] = 'Falha ao eliminar de função.';
$lang['strfunctionupdated'] = 'Função actualizada';
$lang['strfunctionupdatedbad'] = 'Falha na actualização da função.';

// Triggers
$lang['strtrigger'] = 'Gatilho';	
$lang['strtriggers'] = 'Gatilhos';	
$lang['strshowalltriggers'] = 'Exibir todos os gatilhos';	
$lang['strnotrigger'] = 'Não foi encontrado gatilho.';		
$lang['strnotriggers'] = 'Não foram encontrados gatilhos.';		
$lang['strcreatetrigger'] = 'Criar Gatilhos';		
$lang['strtriggerneedsname'] = 'Dê um nome ao gatilho.';	
	$lang['strtriggerneedsfunc'] = 'Especifique uma função para seu gatilho.';
$lang['strtriggercreated'] = 'Gatilho criado.';
$lang['strtriggercreatedbad'] = 'Falha na criação do gatilho.';			
$lang['strconfdroptrigger'] = 'Tem certeza que quer eliminar o gatilho "%s" em "%s"?';	 
$lang['strtriggerdropped'] = 'Gatilho eliminado.'; 
$lang['strtriggerdroppedbad'] = 'Falha ao eliminar o gatilho.';

// Types
$lang['strtype'] = 'Tipo';		
$lang['strtypes'] = 'Tipos';	
$lang['strshowalltypes'] = 'Exibir todos os tipos';	
$lang['strnotype'] = 'Tipo não encontrado.';			
$lang['strnotypes'] = 'Tipos não encontrados.';		
$lang['strcreatetype'] = 'Criar tipo';			
$lang['strtypename'] = 'Nome do tipo';				
$lang['strinputfn'] = 'Função de entrada';			
$lang['stroutputfn'] = 'Função de saída';		
	$lang['strpassbyval'] = 'Passado por valor?';		
$lang['stralignment'] = 'Alinhamento';			
$lang['strelement'] = 'Elemento';				
$lang['strdelimiter'] = 'Delimitador';			
$lang['strstorage'] = 'Armazenamento';				
$lang['strtypeneedsname'] = 'Dê um nome ao seu tipo.';
$lang['strtypeneedslen'] = 'Tipo precisa de extenção.';
$lang['strtypecreated'] = 'Tipo criado';								
$lang['strtypecreatedbad'] = 'Criação de tipo falhou.';					
$lang['strconfdroptype'] = 'Tem certeza que que eliminar o tipo "%s"?';	
$lang['strtypedropped'] = 'Tipo eliminado.';									
$lang['strtypedroppedbad'] = 'Eliminação de tipo falhou.';							

// Schemas
$lang['strschema'] = 'Esquema';	 
$lang['strschemas'] = 'Esquemas';		
$lang['strshowallschemas'] = 'Exibir todos os esquemas';	
$lang['strnoschema'] = 'Esquema não encontado.';		
$lang['strnoschemas'] = 'Não foram encontrados esquemas.';	
$lang['strcreateschema'] = 'Criar esquema';		
$lang['strschemaname'] = 'Nome do esquema';		
$lang['strschemaneedsname'] = 'Dê um nome ao seu esquema.';
$lang['strschemacreated'] = 'Esquema criado';		
$lang['strschemacreatedbad'] = 'Falha na criação dos esquemas.';		
$lang['strconfdropschema'] = 'Tem a certeza que quer eliminar o esquema "%s"?';	
$lang['strschemadropped'] = 'Esquema eliminado.';
$lang['strschemadroppedbad'] = 'Falha ao eliminar o esquema.';

// Reports

// Miscellaneous
$lang['strtopbar'] = '%s a correr  em %s:%s -- Você está ligado como "%s"';
$lang['strtimefmt'] = 'jS M, Y g:iA';


//Missing Strings 16/05/05

$lang['strlocaldocs'] = 'Documentação do PostgreSQL (local)';
$lang['strlogindisallowed'] = 'Autenticação não permitida por questões de sugurança.';
$lang['strfirst'] = '<< Primeiro';
$lang['strlast'] = 'Último >>';
$lang['strtrue'] = 'VERDADEIRO';
$lang['strfalse'] = 'FALSO';
$lang['strcolumn'] = 'Coluna';
$lang['strobjects'] = 'objecto(s)';
$lang['strclustered'] = 'Conjunto?';
$lang['strseparator'] = ': ';
$lang['strexplain'] = 'Explicação';
$lang['strexplainanalyze'] = 'Explicação de Análise';
$lang['strfind'] = 'Procurar';
$lang['stroptions'] = 'Opções';
$lang['strrefresh'] = 'Actualizar';
$lang['strdownload'] = 'Descarreguar';
$lang['strdownloadgzipped'] = 'Descarregar comprimido com gzip';
$lang['strinfo'] = 'Informação';
$lang['stroids'] = 'OIDs';
$lang['stradvanced'] = 'Avançado';
$lang['strvariables'] = 'Variáveis';
$lang['strprocess'] = 'Processo';
$lang['strprocesses'] = 'Processos';
$lang['strsetting'] = 'Configurações';
$lang['streditsql'] = 'Editar SQL';
$lang['strruntime'] = 'Tempo total decorrido: %s ms';
$lang['strpaginate'] = 'Paginar resultados';
$lang['struploadscript'] = 'ou upload um script SQL:';
$lang['strstarttime'] = 'Hora de início';
$lang['strfile'] = 'Ficheiro';
$lang['strfileimported'] = 'Ficheiro importado.';
$lang['strphpversionnotsupported'] = 'Versão do PHP não é suportada. Por favor actualize para a versão %s ou superior.';
$lang['strpostgresqlversionnotsupported'] = 'Versão do PostgreSQL não é suportada. Por favor actualize para a versão %s ou superior.';
$lang['strnoobjects'] = 'Não foram escontrados objectos.';
$lang['strrownotunique'] = 'Não existe identificador único para esta linha.';
$lang['strnouploads'] = 'Upload de ficheiros indisponível.';
$lang['strimporterror'] = 'Erro na importação.';
$lang['strimporterrorline'] = 'Erro ao importar na linha %s.';
$lang['strinsertandrepeat'] = 'Inserir & Repetir';
$lang['strnumcols'] = 'Número de colunas';
$lang['strcolneedsname'] = 'Tem de definir um nome para a coluna.';
$lang['strselectallfields'] = 'Seleccione todos os campos';
$lang['strselectunary'] = 'Operadores unários não podem ter valores.';
$lang['strtablealtered'] = 'Tabela alterada.';
$lang['strtablealteredbad'] = 'Alteração da Tabela falhou.';
$lang['strstructureonly'] = 'Só Estrutura';
$lang['strstructureanddata'] = 'Estrutura e dados';
$lang['strtabbed'] = 'Tabulado';
$lang['strauto'] = 'Auto';
$lang['strconfvacuumtable'] = 'Tem a certeza que pretende aspirar "%s"?';
$lang['strestimatedrowcount'] = 'Contagem de linhas Estimada';
$lang['strsessiondefaults'] = 'Configurações padrão da sessão';
$lang['struserneedsname'] = 'Tem de dar um nome ao seu útilizador.';
$lang['strnogroup'] = 'Grupo não encontrado.';
$lang['strcreategroup'] = 'Criar grupo';
$lang['straddmember'] = 'Adicionar membro';
$lang['strmemberadded'] = 'Membro adicionado.';
$lang['strmemberaddedbad'] = 'Falha ao adicionar Membro.';
$lang['strdropmember'] = 'Retirar membro';
$lang['strconfdropmember'] = 'Tem a certeza que pretende retirar o membro "%s" do grupo "%s"?';
$lang['strmemberdropped'] = 'Membro retirado.';
$lang['strmemberdroppedbad'] = 'Falha ao retirar membro.';
$lang['strgrantor'] = 'Grantor';
$lang['strasterisk'] = '*';
$lang['strreindexgood'] = 'Reindexação completa.';
$lang['strreindexbad'] = 'Falha na Reindexação.';
$lang['strfull'] = 'Cheio';
$lang['strfreeze'] = 'Congelado';
$lang['strforce'] = 'Forçar';
$lang['strsignalsent'] = 'Sinal enviado.';
$lang['strsignalsentbad'] = 'Falha ao enviar sinal.';
$lang['strallobjects'] = 'Todos os objectos';
$lang['strviewneedsfields'] = 'Tem de específicar a coluna que pretende seleccionar para a sua vista.';
$lang['strviewlink'] = 'ligar chaves';
$lang['strviewconditions'] = 'Condições Adicionais';
$lang['strcreateviewwiz'] = 'Criar vista com assistente';
$lang['strsequencereset'] = 'Limpar sequência.';
$lang['strsequenceresetbad'] = 'Falha ao limpar sequência.';
$lang['strindex'] = 'Index';
$lang['strconfcluster'] = 'Tem a certeza que pretende conjugar "%s"?';
$lang['strclusteredgood'] = 'Conjugação completa.';
$lang['strclusteredbad'] = 'Falha ao conjugar.';
$lang['strcreateplfunction'] = 'Criar função Create SQL/PL';
$lang['strcreateinternalfunction'] = 'Criar função interna';
$lang['strcreatecfunction'] = 'Criar função em C';
$lang['strobjectfile'] = 'Ficheiro Objecto';
$lang['strlinksymbol'] = 'Ligar Símbolo';
$lang['strtriggeraltered'] = 'Trigger Alterado.';
$lang['strtriggeralteredbad'] = 'Falha ao alterar Trigger.';
$lang['strcreatecomptype'] = 'Criar tipo composto';
$lang['strtypeneedsfield'] = 'Tem de específicar pelo menos um campo.';
$lang['strtypeneedscols'] = 'Tem de específicar um número válido de campos.';
$lang['strflavor'] = 'Sabor';
$lang['strbasetype'] = 'Base';
$lang['strcompositetype'] = 'Compôr';
$lang['strpseudotype'] = 'Pseudo';
$lang['strschemaaltered'] = 'Esquema Alterado.';
$lang['strschemaalteredbad'] = 'Falha ao alterar o esquema.';
$lang['strsearchpath'] = 'Caminho de pesquisa no esquema';
$lang['strdomain'] = 'Domínio';
$lang['strdomains'] = 'Domínios';
$lang['strshowalldomains'] = 'Lista todos os domínios';
$lang['strnodomains'] = 'Não foram encontrados domínios.';
$lang['strcreatedomain'] = 'Criar domínio';
$lang['strdomaindropped'] = 'Eliminar domínio.';
$lang['strdomaindroppedbad'] = 'Falha ao eliminar o domínio.';
$lang['strconfdropdomain'] = 'Tem a certeza que pretende eliminar o dominio "%s"?';
$lang['strdomainneedsname'] = 'Tem de específicar um nome para o seu domínio.';
$lang['strdomaincreated'] = 'Domínio criado.';
$lang['strdomaincreatedbad'] = 'Falha ao criar domínio.';
$lang['strdomainaltered'] = 'Alterar domínio.';
$lang['strdomainalteredbad'] = 'Falha ao alterar domínio.';
$lang['stroperator'] = 'Operador';
$lang['strshowalloperators'] = 'Lista todos os operadores';
$lang['strnooperator'] = 'Não foi encontrado o operador.';
$lang['strnooperators'] = 'Não foram encontrados operadores.';
$lang['strcreateoperator'] = 'Criar operador';
$lang['strleftarg'] = 'Tipo de ARGumento esquerdo';
$lang['strrightarg'] = 'Tipo de ARGumento direito';
$lang['strcommutator'] = 'Comutador';
$lang['strnegator'] = 'Negador';
$lang['strrestrict'] = 'Restrito';
$lang['strjoin'] = 'Juntar';
$lang['strhashes'] = 'Referências';
$lang['strmerges'] = 'Mesclrar';
$lang['strleftsort'] = 'Ordenação esquerda';
$lang['strrightsort'] = 'Ordenação direita';
$lang['strlessthan'] = 'Menor que';
$lang['strgreaterthan'] = 'Maior que';
$lang['stroperatorneedsname'] = 'Tem de específicar um nome para o operador.';
$lang['stroperatorcreated'] = 'Operador criado';
$lang['stroperatorcreatedbad'] = 'Falha ao criar operador.';
$lang['strconfdropoperator'] = 'Tem a certeza que pretende eliminar o operador "%s"?';
$lang['stroperatordropped'] = 'Operador eliminado.';
$lang['stroperatordroppedbad'] = 'Falha ao eliminar o operador.';
$lang['strcasts'] = 'Molde';
$lang['strnocasts'] = 'Não foram encontrador moldes.';
$lang['strsourcetype'] = 'Tipo de fonte';
$lang['strtargettype'] = 'Tipo de alvo';
$lang['strimplicit'] = 'Implicito';
$lang['strinassignment'] = 'Em assignamento';
$lang['strbinarycompat'] = '(Binario compativél)';
$lang['strconversions'] = 'Conversões';
$lang['strnoconversions'] = 'Não foram encontradas conversões.';
$lang['strsourceencoding'] = 'Codificação da fonte';
$lang['strtargetencoding'] = 'Codificação do alvo';
$lang['strlanguages'] = 'Línguas';
$lang['strnolanguages'] = 'Não foram encontradas línguas.';
$lang['strtrusted'] = 'Confiado';
$lang['strnoinfo'] = 'Informação indisponível.';
$lang['strreferringtables'] = 'Tabelas de referência';
$lang['strparenttables'] = 'Tabelas pai';
$lang['strchildtables'] = 'Tabelas filho';
$lang['strnoaggregates'] = 'Não foram encontrados agregados.';
$lang['stralltypes'] = '(Todos os tipos)';
$lang['stropclasses'] = 'Classes Op';
$lang['strnoopclasses'] = 'Não foram encontrados operadores de classes.';
$lang['straccessmethod'] = 'Método de acesso';
$lang['strrowperf'] = 'Performance das linhas';
$lang['strioperf'] = 'Performance de E/S';
$lang['stridxrowperf'] = 'Performance de indexação de linhas';
$lang['stridxioperf'] = 'Performance em indexação E/S';
$lang['strpercent'] = '%';
$lang['strsequential'] = 'Sequêncial';
$lang['strscan'] = 'Pesquisar';
$lang['strread'] = 'Lêr';
$lang['strfetch'] = 'Descarregar';
$lang['strheap'] = 'Fila';
$lang['strtoast'] = 'QUEIMAR';
$lang['strtoastindex'] = 'QUEIMAR Index';
$lang['strcache'] = 'Cache';
$lang['strdisk'] = 'Disco';
$lang['strrows2'] = 'Linhas';
$lang['strtablespace'] = 'Espaço de Tabela';
$lang['strtablespaces'] = 'Espaços de Tabela';
$lang['strshowalltablespaces'] = 'Lista todos os espaços de tabela';
$lang['strnotablespaces'] = 'Não foram encontrados espaços de tabela.';
$lang['strcreatetablespace'] = 'Criar espaço de tabela';
$lang['strlocation'] = 'Localização';
$lang['strtablespaceneedsname'] = 'Tem de específicar um nome para o espaço de tabela.';
$lang['strtablespaceneedsloc'] = 'Tem de específicar um directório no qual irá criar o espaço de tabela.';
$lang['strtablespacecreated'] = 'Espaço de Tabela criado.';
$lang['strtablespacecreatedbad'] = 'Falha ao criar espaço de tabela.';
$lang['strconfdroptablespace'] = 'Tem a certeza que pretende eliminar o espaço de tabela "%s"?';
$lang['strtablespacedropped'] = 'Espaço de tabela eliminado.';
$lang['strtablespacedroppedbad'] = 'Falha ao eliminar o espaço de tabela.';
$lang['strtablespacealtered'] = 'Espaço de tabela alterado.';
$lang['strtablespacealteredbad'] = 'Alteração do Espaçamento de Tabela falhou.';
$lang['strhelp'] = 'Ajuda';
$lang['strhelpicon'] = '?';

?>
