<?php
	/**
	 * Brazilian Portuguese language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Plugin de relatório';
	$plugin_lang['strnoreportsdb'] = 'Você não criou a base de dados para relatórios. Leia o arquivo INSTALL para resolução.';

	// Reports
	$plugin_lang['strreport'] = 'Relatório';
	$plugin_lang['strreports'] = 'Relatórios';
	$plugin_lang['strshowallreports'] = 'Exibir todos os relatórios';
	$plugin_lang['strnoreports'] = 'Nenhum relatório encontrado.';
	$plugin_lang['strcreatereport'] = 'Criar relatório';
	$plugin_lang['strreportdropped'] = 'Relatório deletado.';
	$plugin_lang['strreportdroppedbad'] = 'Falha ao deletar o relatório.';
	$plugin_lang['strconfdropreport'] = 'Você têm certeza que deseja deletar o relatório "%s"?';
	$plugin_lang['strreportneedsname'] = 'Você deve informar um nome para o seu relatório.';
	$plugin_lang['strreportneedsdef'] = 'Você deve informar o SQL para o seu relatório.';
	$plugin_lang['strreportcreated'] = 'Relatório salvo.';
	$plugin_lang['strreportcreatedbad'] = 'Falha ao salvar o relatório.';
?>
