<?php
/**
 * Simplified Chinese language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Cuiyan (cysoft) <cysoft@php.net>
 */

$ADODB_LANG_ARRAY = array (
			'LANG'                      => 'cn',
            DB_ERROR                    => '未知错误',
            DB_ERROR_ALREADY_EXISTS     => '已经存在',
            DB_ERROR_CANNOT_CREATE      => '不能创建',
            DB_ERROR_CANNOT_DELETE      => '不能删除',
            DB_ERROR_CANNOT_DROP        => '不能丢弃',
            DB_ERROR_CONSTRAINT         => '约束限制',
            DB_ERROR_DIVZERO            => '被0除',
            DB_ERROR_INVALID            => '无效',
            DB_ERROR_INVALID_DATE       => '无效的日期或者时间',
            DB_ERROR_INVALID_NUMBER     => '无效的数字',
            DB_ERROR_MISMATCH           => '不匹配',
            DB_ERROR_NODBSELECTED       => '没有数据库被选择',
            DB_ERROR_NOSUCHFIELD        => '没有相应的字段',
            DB_ERROR_NOSUCHTABLE        => '没有相应的表',
            DB_ERROR_NOT_CAPABLE        => '数据库后台不兼容',
            DB_ERROR_NOT_FOUND          => '没有发现',
            DB_ERROR_NOT_LOCKED         => '没有被锁定',
            DB_ERROR_SYNTAX             => '语法错误',
            DB_ERROR_UNSUPPORTED        => '不支持',
            DB_ERROR_VALUE_COUNT_ON_ROW => '在行上累计值',
            DB_ERROR_INVALID_DSN        => '无效的数据源 (DSN)',
            DB_ERROR_CONNECT_FAILED     => '连接失败',
            0	                       => '没有错误', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => '提供的数据不能符合要求',
            DB_ERROR_EXTENSION_NOT_FOUND=> '扩展没有被发现',
            DB_ERROR_NOSUCHDB           => '没有相应的数据库',
            DB_ERROR_ACCESS_VIOLATION   => '没有合适的权限'
);
