<?php
/**
 * Russian language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Cyrill Malevanov <cyrill@malevanov.spb.ru>
 */

$ADODB_LANG_ARRAY = array (
             'LANG'                      => 'ru',
            DB_ERROR                    => 'неизвестная ошибка',
            DB_ERROR_ALREADY_EXISTS     => 'уже существует',
            DB_ERROR_CANNOT_CREATE      => 'невозможно создать',
            DB_ERROR_CANNOT_DELETE      => 'невозможно удалить',
            DB_ERROR_CANNOT_DROP        => 'невозможно удалить (drop)',
            DB_ERROR_CONSTRAINT         => 'нарушение условий проверки',
            DB_ERROR_DIVZERO            => 'деление на 0',
            DB_ERROR_INVALID            => 'неправильно',
            DB_ERROR_INVALID_DATE       => 'некорректная дата или время',
            DB_ERROR_INVALID_NUMBER     => 'некорректное число',
            DB_ERROR_MISMATCH           => 'ошибка',
            DB_ERROR_NODBSELECTED       => 'БД не выбрана',
            DB_ERROR_NOSUCHFIELD        => 'не существует поле',
            DB_ERROR_NOSUCHTABLE        => 'не существует таблица',
            DB_ERROR_NOT_CAPABLE        => 'СУБД не в состоянии',
            DB_ERROR_NOT_FOUND          => 'не найдено',
            DB_ERROR_NOT_LOCKED         => 'не заблокировано',
            DB_ERROR_SYNTAX             => 'синтаксическая ошибка',
            DB_ERROR_UNSUPPORTED        => 'не поддерживается',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'счетчик значений в строке',
            DB_ERROR_INVALID_DSN        => 'неправильная DSN',
            DB_ERROR_CONNECT_FAILED     => 'соединение неуспешно',
            0                               => 'нет ошибки', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'предоставлено недостаточно данных',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'расширение не найдено',
            DB_ERROR_NOSUCHDB           => 'не существует БД',
            DB_ERROR_ACCESS_VIOLATION   => 'недостаточно прав доступа'
);
