<?php
/**
 * Ukrainian language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Alex Rootoff <rootoff@pisem.net>
 */

$ADODB_LANG_ARRAY = array (
             'LANG'                      => 'uk',
            DB_ERROR                    => 'невідома помилка',
            DB_ERROR_ALREADY_EXISTS     => 'вже існує',
            DB_ERROR_CANNOT_CREATE      => 'неможливо створити',
            DB_ERROR_CANNOT_DELETE      => 'неможливо видалити',
            DB_ERROR_CANNOT_DROP        => 'неможливо знищити (drop)',
            DB_ERROR_CONSTRAINT         => 'порушення умов перевірки',
            DB_ERROR_DIVZERO            => 'ділення на 0',
            DB_ERROR_INVALID            => 'неправильно',
            DB_ERROR_INVALID_DATE       => 'неправильна дата чи час',
            DB_ERROR_INVALID_NUMBER     => 'неправильне число',
            DB_ERROR_MISMATCH           => 'помилка',
            DB_ERROR_NODBSELECTED       => 'не вибрано БД',
            DB_ERROR_NOSUCHFIELD        => 'не існує поле',
            DB_ERROR_NOSUCHTABLE        => 'не існує таблиця',
            DB_ERROR_NOT_CAPABLE        => 'СУБД не в стані',
            DB_ERROR_NOT_FOUND          => 'не знайдено',
            DB_ERROR_NOT_LOCKED         => 'не заблоковано',
            DB_ERROR_SYNTAX             => 'синтаксична помилка',
            DB_ERROR_UNSUPPORTED        => 'не підтримується',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'рахівник значень в стрічці',
            DB_ERROR_INVALID_DSN        => 'неправильна DSN',
            DB_ERROR_CONNECT_FAILED     => 'з\'єднання неуспішне',
            0                               => 'все гаразд', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'надано недостатньо даних',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'розширення не знайдено',
            DB_ERROR_NOSUCHDB           => 'не існує БД',
            DB_ERROR_ACCESS_VIOLATION   => 'недостатньо прав доступа'
);
