<?php
/**
 * Thai language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Trirat Petchsingh <rosskouk@gmail.com>
 */

$ADODB_LANG_ARRAY = array (
			'LANG'						=> 'th',
			DB_ERROR					=> 'error ไม่รู้สาเหตุ',
			DB_ERROR_ALREADY_EXISTS		=> 'มี�?ล้ว',
			DB_ERROR_CANNOT_CREATE		=> 'สร้างไม่ได้',
			DB_ERROR_CANNOT_DELETE		=> 'ลบไม่ได้',
			DB_ERROR_CANNOT_DROP		=> 'drop ไม่ได้',
			DB_ERROR_CONSTRAINT			=> 'constraint violation',
			DB_ERROR_DIVZERO			=> 'หา�?ด้วยสู�?',
			DB_ERROR_INVALID			=> 'ไม่ valid',
			DB_ERROR_INVALID_DATE		=> 'วันที่ เวลา ไม่ valid',
			DB_ERROR_INVALID_NUMBER		=> 'เลขไม่ valid',
			DB_ERROR_MISMATCH			=> 'mismatch',
			DB_ERROR_NODBSELECTED		=> 'ไม่ได้เลือ�?�?านข้อมูล',
			DB_ERROR_NOSUCHFIELD		=> 'ไม่มีฟีลด์นี้',
			DB_ERROR_NOSUCHTABLE		=> 'ไม่มีตารางนี้',
			DB_ERROR_NOT_CAPABLE		=> 'DB backend not capable',
			DB_ERROR_NOT_FOUND			=> 'ไม่พบ',
			DB_ERROR_NOT_LOCKED			=> 'ไม่ได้ล๊อ�?',
			DB_ERROR_SYNTAX				=> 'ผิด syntax',
			DB_ERROR_UNSUPPORTED		=> 'ไม่ support',
			DB_ERROR_VALUE_COUNT_ON_ROW => 'value count on row',
			DB_ERROR_INVALID_DSN		=> 'invalid DSN',
			DB_ERROR_CONNECT_FAILED		=> 'ไม่สามารถ connect',
			0							=> 'no error',
			DB_ERROR_NEED_MORE_DATA		=> 'ข้อมูลไม่เพียงพอ',
			DB_ERROR_EXTENSION_NOT_FOUND=> 'ไม่พบ extension',
			DB_ERROR_NOSUCHDB			=> 'ไม่มีข้อมูลนี้',
			DB_ERROR_ACCESS_VIOLATION	=> 'permissions ไม่พอ'
);
