<?php
	/**
	 * Japanese language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'レポートデータベースが作成されていません。ディレクトリにある INSTALL ファイルを読んでください。';

	// Reports
	$plugin_lang['strreport'] = 'レポート';
	$plugin_lang['strreports'] = 'レポート';
	$plugin_lang['strshowallreports'] = 'すべてのレポートを表示する';
	$plugin_lang['strnoreports'] = 'レポートが見つかりません。';
	$plugin_lang['strcreatereport'] = 'レポートを作成する';
	$plugin_lang['strreportdropped'] = 'レポートを破棄しました。';
	$plugin_lang['strreportdroppedbad'] = 'レポートの破棄に失敗しました。';
	$plugin_lang['strconfdropreport'] = '本当にレポート「%s」を破棄しますか?';
	$plugin_lang['strreportneedsname'] = 'レポート名を指定する必要があります。';
	$plugin_lang['strreportneedsdef'] = 'レポート用のSQLを指定する必要があります。';
	$plugin_lang['strreportcreated'] = 'レポートの保存をしました。';
	$plugin_lang['strreportcreatedbad'] = 'レポートの保存に失敗しました。';
?>
