<?php
/**
 * Esperanto language strings.
 *
 * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
 *
 * @package ADOdb
 * @link https://adodb.org Project's web site and documentation
 * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
 *
 * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
 * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
 * any later version. This means you can use it in proprietary products.
 * See the LICENSE.md file distributed with this source code for details.
 * @license BSD-3-Clause
 * @license LGPL-2.1-or-later
 *
 * @copyright 2000-2013 John Lim
 * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
 * @author Antono Vasiljev <anders@brainactive.org>
 */

$ADODB_LANG_ARRAY = array (
             'LANG'                      => 'eo',
            DB_ERROR                    => 'nekonata eraro',
            DB_ERROR_ALREADY_EXISTS     => 'jam ekzistas',
            DB_ERROR_CANNOT_CREATE      => 'maleblas krei',
            DB_ERROR_CANNOT_DELETE      => 'maleblas elimini',
            DB_ERROR_CANNOT_DROP        => 'maleblas elimini (drop)',
            DB_ERROR_CONSTRAINT         => 'rompo de kondiĉoj de provo',
            DB_ERROR_DIVZERO            => 'divido per 0 (nul)',
            DB_ERROR_INVALID            => 'malregule',
            DB_ERROR_INVALID_DATE       => 'malregula dato kaj tempo',
            DB_ERROR_INVALID_NUMBER     => 'malregula nombro',
            DB_ERROR_MISMATCH           => 'eraro',
            DB_ERROR_NODBSELECTED       => 'datumbazo ne elektita',
            DB_ERROR_NOSUCHFIELD        => 'ne ekzistas kampo',
            DB_ERROR_NOSUCHTABLE        => 'ne ekzistas tabelo',
            DB_ERROR_NOT_CAPABLE        => 'DBMS ne povas',
            DB_ERROR_NOT_FOUND          => 'ne trovita',
            DB_ERROR_NOT_LOCKED         => 'ne blokita',
            DB_ERROR_SYNTAX             => 'sintaksa eraro',
            DB_ERROR_UNSUPPORTED        => 'ne apogata',
            DB_ERROR_VALUE_COUNT_ON_ROW => 'nombrilo de valoroj en linio',
            DB_ERROR_INVALID_DSN        => 'malregula DSN-o',
            DB_ERROR_CONNECT_FAILED     => 'konekto malsukcesa',
            0                               => 'ĉio bone', // DB_OK
            DB_ERROR_NEED_MORE_DATA     => 'ne sufiĉe da datumo',
            DB_ERROR_EXTENSION_NOT_FOUND=> 'etendo ne trovita',
            DB_ERROR_NOSUCHDB           => 'datumbazo ne ekzistas',
            DB_ERROR_ACCESS_VIOLATION   => 'ne sufiĉe da rajto por atingo'
);
